v1alpha1

package
v0.0.0-...-6fe2522 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 3, 2023 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

+kubebuilder:object:generate=true +groupName=file.vsphere.upbound.io +versionName=v1alpha1

Index

Constants

const (
	CRDGroup   = "file.vsphere.upbound.io"
	CRDVersion = "v1alpha1"
)

Package type metadata.

Variables

var (
	File_Kind             = "File"
	File_GroupKind        = schema.GroupKind{Group: CRDGroup, Kind: File_Kind}.String()
	File_KindAPIVersion   = File_Kind + "." + CRDGroupVersion.String()
	File_GroupVersionKind = CRDGroupVersion.WithKind(File_Kind)
)

Repository type metadata.

var (
	// CRDGroupVersion is the API Group Version used to register the objects
	CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)

Functions

This section is empty.

Types

type File

type File struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`
	Spec              FileSpec   `json:"spec"`
	Status            FileStatus `json:"status,omitempty"`
}

File is the Schema for the Files API. Provides a VMware vSphere file resource. This can be used to upload files (e.g. .iso and . +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,vsphere}

func (*File) DeepCopy

func (in *File) DeepCopy() *File

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new File.

func (*File) DeepCopyInto

func (in *File) DeepCopyInto(out *File)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*File) DeepCopyObject

func (in *File) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*File) GetCondition

func (mg *File) GetCondition(ct xpv1.ConditionType) xpv1.Condition

GetCondition of this File.

func (*File) GetConnectionDetailsMapping

func (tr *File) GetConnectionDetailsMapping() map[string]string

GetConnectionDetailsMapping for this File

func (*File) GetDeletionPolicy

func (mg *File) GetDeletionPolicy() xpv1.DeletionPolicy

GetDeletionPolicy of this File.

func (*File) GetID

func (tr *File) GetID() string

GetID returns ID of underlying Terraform resource of this File

func (*File) GetObservation

func (tr *File) GetObservation() (map[string]any, error)

GetObservation of this File

func (*File) GetParameters

func (tr *File) GetParameters() (map[string]any, error)

GetParameters of this File

func (*File) GetProviderConfigReference

func (mg *File) GetProviderConfigReference() *xpv1.Reference

GetProviderConfigReference of this File.

func (*File) GetProviderReference

func (mg *File) GetProviderReference() *xpv1.Reference

GetProviderReference of this File. Deprecated: Use GetProviderConfigReference.

func (*File) GetPublishConnectionDetailsTo

func (mg *File) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo

GetPublishConnectionDetailsTo of this File.

func (*File) GetTerraformResourceType

func (mg *File) GetTerraformResourceType() string

GetTerraformResourceType returns Terraform resource type for this File

func (*File) GetTerraformSchemaVersion

func (tr *File) GetTerraformSchemaVersion() int

GetTerraformSchemaVersion returns the associated Terraform schema version

func (*File) GetWriteConnectionSecretToReference

func (mg *File) GetWriteConnectionSecretToReference() *xpv1.SecretReference

GetWriteConnectionSecretToReference of this File.

func (*File) LateInitialize

func (tr *File) LateInitialize(attrs []byte) (bool, error)

LateInitialize this File using its observed tfState. returns True if there are any spec changes for the resource.

func (*File) SetConditions

func (mg *File) SetConditions(c ...xpv1.Condition)

SetConditions of this File.

func (*File) SetDeletionPolicy

func (mg *File) SetDeletionPolicy(r xpv1.DeletionPolicy)

SetDeletionPolicy of this File.

func (*File) SetObservation

func (tr *File) SetObservation(obs map[string]any) error

SetObservation for this File

func (*File) SetParameters

func (tr *File) SetParameters(params map[string]any) error

SetParameters for this File

func (*File) SetProviderConfigReference

func (mg *File) SetProviderConfigReference(r *xpv1.Reference)

SetProviderConfigReference of this File.

func (*File) SetProviderReference

func (mg *File) SetProviderReference(r *xpv1.Reference)

SetProviderReference of this File. Deprecated: Use SetProviderConfigReference.

func (*File) SetPublishConnectionDetailsTo

func (mg *File) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)

SetPublishConnectionDetailsTo of this File.

func (*File) SetWriteConnectionSecretToReference

func (mg *File) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)

SetWriteConnectionSecretToReference of this File.

type FileList

type FileList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []File `json:"items"`
}

FileList contains a list of Files

func (*FileList) DeepCopy

func (in *FileList) DeepCopy() *FileList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FileList.

func (*FileList) DeepCopyInto

func (in *FileList) DeepCopyInto(out *FileList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*FileList) DeepCopyObject

func (in *FileList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*FileList) GetItems

func (l *FileList) GetItems() []resource.Managed

GetItems of this FileList.

type FileObservation

type FileObservation struct {
	ID *string `json:"id,omitempty" tf:"id,omitempty"`
}

func (*FileObservation) DeepCopy

func (in *FileObservation) DeepCopy() *FileObservation

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FileObservation.

func (*FileObservation) DeepCopyInto

func (in *FileObservation) DeepCopyInto(out *FileObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type FileParameters

type FileParameters struct {

	// Create directories in destination_file
	// path parameter on first apply if any are missing for copy operation.
	// +kubebuilder:validation:Optional
	CreateDirectories *bool `json:"createDirectories,omitempty" tf:"create_directories,omitempty"`

	// The name of a datacenter to which the file will be
	// uploaded.
	// +kubebuilder:validation:Optional
	Datacenter *string `json:"datacenter,omitempty" tf:"datacenter,omitempty"`

	// The name of the datastore to which to upload the
	// file.
	// +kubebuilder:validation:Required
	Datastore *string `json:"datastore" tf:"datastore,omitempty"`

	// The path to where the file should be uploaded
	// or copied to on the destination datastore in vSphere.
	// +kubebuilder:validation:Required
	DestinationFile *string `json:"destinationFile" tf:"destination_file,omitempty"`

	// The name of a datacenter from which the file
	// will be copied. Forces a new resource if changed.
	// +kubebuilder:validation:Optional
	SourceDatacenter *string `json:"sourceDatacenter,omitempty" tf:"source_datacenter,omitempty"`

	// The name of the datastore from which file will
	// be copied. Forces a new resource if changed.
	// +kubebuilder:validation:Optional
	SourceDatastore *string `json:"sourceDatastore,omitempty" tf:"source_datastore,omitempty"`

	// Forces a new resource if changed.
	// +kubebuilder:validation:Required
	SourceFile *string `json:"sourceFile" tf:"source_file,omitempty"`
}

func (*FileParameters) DeepCopy

func (in *FileParameters) DeepCopy() *FileParameters

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FileParameters.

func (*FileParameters) DeepCopyInto

func (in *FileParameters) DeepCopyInto(out *FileParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type FileSpec

type FileSpec struct {
	v1.ResourceSpec `json:",inline"`
	ForProvider     FileParameters `json:"forProvider"`
}

FileSpec defines the desired state of File

func (*FileSpec) DeepCopy

func (in *FileSpec) DeepCopy() *FileSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FileSpec.

func (*FileSpec) DeepCopyInto

func (in *FileSpec) DeepCopyInto(out *FileSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type FileStatus

type FileStatus struct {
	v1.ResourceStatus `json:",inline"`
	AtProvider        FileObservation `json:"atProvider,omitempty"`
}

FileStatus defines the observed state of File.

func (*FileStatus) DeepCopy

func (in *FileStatus) DeepCopy() *FileStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new FileStatus.

func (*FileStatus) DeepCopyInto

func (in *FileStatus) DeepCopyInto(out *FileStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to