v1alpha1

package
v0.0.0-...-6fe2522 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 3, 2023 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Overview

+kubebuilder:object:generate=true +groupName=vappcontainer.vsphere.upbound.io +versionName=v1alpha1

Index

Constants

const (
	CRDGroup   = "vappcontainer.vsphere.upbound.io"
	CRDVersion = "v1alpha1"
)

Package type metadata.

Variables

var (
	Container_Kind             = "Container"
	Container_GroupKind        = schema.GroupKind{Group: CRDGroup, Kind: Container_Kind}.String()
	Container_KindAPIVersion   = Container_Kind + "." + CRDGroupVersion.String()
	Container_GroupVersionKind = CRDGroupVersion.WithKind(Container_Kind)
)

Repository type metadata.

var (
	// CRDGroupVersion is the API Group Version used to register the objects
	CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion}

	// SchemeBuilder is used to add go types to the GroupVersionKind scheme
	SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion}

	// AddToScheme adds the types in this group-version to the given scheme.
	AddToScheme = SchemeBuilder.AddToScheme
)

Functions

This section is empty.

Types

type Container

type Container struct {
	metav1.TypeMeta   `json:",inline"`
	metav1.ObjectMeta `json:"metadata,omitempty"`
	Spec              ContainerSpec   `json:"spec"`
	Status            ContainerStatus `json:"status,omitempty"`
}

Container is the Schema for the Containers API. Provides a VMware vSphere vApp container resource. This can be used to create and manage vApp container. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,vsphere}

func (*Container) DeepCopy

func (in *Container) DeepCopy() *Container

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Container.

func (*Container) DeepCopyInto

func (in *Container) DeepCopyInto(out *Container)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*Container) DeepCopyObject

func (in *Container) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*Container) GetCondition

func (mg *Container) GetCondition(ct xpv1.ConditionType) xpv1.Condition

GetCondition of this Container.

func (*Container) GetConnectionDetailsMapping

func (tr *Container) GetConnectionDetailsMapping() map[string]string

GetConnectionDetailsMapping for this Container

func (*Container) GetDeletionPolicy

func (mg *Container) GetDeletionPolicy() xpv1.DeletionPolicy

GetDeletionPolicy of this Container.

func (*Container) GetID

func (tr *Container) GetID() string

GetID returns ID of underlying Terraform resource of this Container

func (*Container) GetObservation

func (tr *Container) GetObservation() (map[string]any, error)

GetObservation of this Container

func (*Container) GetParameters

func (tr *Container) GetParameters() (map[string]any, error)

GetParameters of this Container

func (*Container) GetProviderConfigReference

func (mg *Container) GetProviderConfigReference() *xpv1.Reference

GetProviderConfigReference of this Container.

func (*Container) GetProviderReference

func (mg *Container) GetProviderReference() *xpv1.Reference

GetProviderReference of this Container. Deprecated: Use GetProviderConfigReference.

func (*Container) GetPublishConnectionDetailsTo

func (mg *Container) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo

GetPublishConnectionDetailsTo of this Container.

func (*Container) GetTerraformResourceType

func (mg *Container) GetTerraformResourceType() string

GetTerraformResourceType returns Terraform resource type for this Container

func (*Container) GetTerraformSchemaVersion

func (tr *Container) GetTerraformSchemaVersion() int

GetTerraformSchemaVersion returns the associated Terraform schema version

func (*Container) GetWriteConnectionSecretToReference

func (mg *Container) GetWriteConnectionSecretToReference() *xpv1.SecretReference

GetWriteConnectionSecretToReference of this Container.

func (*Container) LateInitialize

func (tr *Container) LateInitialize(attrs []byte) (bool, error)

LateInitialize this Container using its observed tfState. returns True if there are any spec changes for the resource.

func (*Container) SetConditions

func (mg *Container) SetConditions(c ...xpv1.Condition)

SetConditions of this Container.

func (*Container) SetDeletionPolicy

func (mg *Container) SetDeletionPolicy(r xpv1.DeletionPolicy)

SetDeletionPolicy of this Container.

func (*Container) SetObservation

func (tr *Container) SetObservation(obs map[string]any) error

SetObservation for this Container

func (*Container) SetParameters

func (tr *Container) SetParameters(params map[string]any) error

SetParameters for this Container

func (*Container) SetProviderConfigReference

func (mg *Container) SetProviderConfigReference(r *xpv1.Reference)

SetProviderConfigReference of this Container.

func (*Container) SetProviderReference

func (mg *Container) SetProviderReference(r *xpv1.Reference)

SetProviderReference of this Container. Deprecated: Use SetProviderConfigReference.

func (*Container) SetPublishConnectionDetailsTo

func (mg *Container) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)

SetPublishConnectionDetailsTo of this Container.

func (*Container) SetWriteConnectionSecretToReference

func (mg *Container) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)

SetWriteConnectionSecretToReference of this Container.

type ContainerList

type ContainerList struct {
	metav1.TypeMeta `json:",inline"`
	metav1.ListMeta `json:"metadata,omitempty"`
	Items           []Container `json:"items"`
}

ContainerList contains a list of Containers

func (*ContainerList) DeepCopy

func (in *ContainerList) DeepCopy() *ContainerList

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerList.

func (*ContainerList) DeepCopyInto

func (in *ContainerList) DeepCopyInto(out *ContainerList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*ContainerList) DeepCopyObject

func (in *ContainerList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

func (*ContainerList) GetItems

func (l *ContainerList) GetItems() []resource.Managed

GetItems of this ContainerList.

type ContainerObservation

type ContainerObservation struct {
	ID *string `json:"id,omitempty" tf:"id,omitempty"`
}

func (*ContainerObservation) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerObservation.

func (*ContainerObservation) DeepCopyInto

func (in *ContainerObservation) DeepCopyInto(out *ContainerObservation)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ContainerParameters

type ContainerParameters struct {

	// Determines if the reservation on a vApp
	// container can grow beyond the specified value if the parent resource pool has
	// unreserved resources. Default: true
	// Determines if the reservation on a vApp container can grow beyond the specified value, if the parent resource pool has unreserved resources.
	// +kubebuilder:validation:Optional
	CPUExpandable *bool `json:"cpuExpandable,omitempty" tf:"cpu_expandable,omitempty"`

	// The CPU utilization of a vApp container will not
	// exceed this limit, even if there are available resources. Set to -1 for
	// unlimited.
	// Default: -1
	// The utilization of a vApp container will not exceed this limit, even if there are available resources. Set to -1 for unlimited.
	// +kubebuilder:validation:Optional
	CPULimit *float64 `json:"cpuLimit,omitempty" tf:"cpu_limit,omitempty"`

	// Amount of CPU (MHz) that is guaranteed
	// available to the vApp container. Default: 0
	// Amount of CPU (MHz) that is guaranteed available to the vApp container.
	// +kubebuilder:validation:Optional
	CPUReservation *float64 `json:"cpuReservation,omitempty" tf:"cpu_reservation,omitempty"`

	// The CPU allocation level. The level is a
	// simplified view of shares. Levels map to a pre-determined set of numeric
	// values for shares. Can be one of low, normal, high, or custom. When
	// low, normal, or high are specified values in cpu_shares will be
	// ignored.  Default: normal
	// The allocation level. The level is a simplified view of shares. Levels map to a pre-determined set of numeric values for shares. Can be one of low, normal, high, or custom.
	// +kubebuilder:validation:Optional
	CPUShareLevel *string `json:"cpuShareLevel,omitempty" tf:"cpu_share_level,omitempty"`

	// The number of shares allocated for CPU. Used to
	// determine resource allocation in case of resource contention. If this is set,
	// cpu_share_level must be custom.
	// The number of shares allocated. Used to determine resource allocation in case of resource contention. If this is set, cpu_share_level must be custom.
	// +kubebuilder:validation:Optional
	CPUShares *float64 `json:"cpuShares,omitempty" tf:"cpu_shares,omitempty"`

	// A list of custom attributes to set on this resource.
	// +kubebuilder:validation:Optional
	CustomAttributes map[string]*string `json:"customAttributes,omitempty" tf:"custom_attributes,omitempty"`

	// Determines if the reservation on a vApp
	// container can grow beyond the specified value if the parent resource pool has
	// unreserved resources. Default: true
	// Determines if the reservation on a vApp container can grow beyond the specified value, if the parent resource pool has unreserved resources.
	// +kubebuilder:validation:Optional
	MemoryExpandable *bool `json:"memoryExpandable,omitempty" tf:"memory_expandable,omitempty"`

	// The CPU utilization of a vApp container will not
	// exceed this limit, even if there are available resources. Set to -1 for
	// unlimited. Default: -1
	// The utilization of a vApp container will not exceed this limit, even if there are available resources. Set to -1 for unlimited.
	// +kubebuilder:validation:Optional
	MemoryLimit *float64 `json:"memoryLimit,omitempty" tf:"memory_limit,omitempty"`

	// Amount of CPU (MHz) that is guaranteed
	// available to the vApp container. Default: 0
	// Amount of memory (MB) that is guaranteed available to the vApp container.
	// +kubebuilder:validation:Optional
	MemoryReservation *float64 `json:"memoryReservation,omitempty" tf:"memory_reservation,omitempty"`

	// The CPU allocation level. The level is a
	// simplified view of shares. Levels map to a pre-determined set of numeric
	// values for shares. Can be one of low, normal, high, or custom. When
	// low, normal, or high are specified values in memory_shares will be
	// ignored.  Default: normal
	// The allocation level. The level is a simplified view of shares. Levels map to a pre-determined set of numeric values for shares. Can be one of low, normal, high, or custom.
	// +kubebuilder:validation:Optional
	MemoryShareLevel *string `json:"memoryShareLevel,omitempty" tf:"memory_share_level,omitempty"`

	// The number of shares allocated for CPU. Used to
	// determine resource allocation in case of resource contention. If this is set,
	// memory_share_level must be custom.
	// The number of shares allocated. Used to determine resource allocation in case of resource contention. If this is set, memory_share_level must be custom.
	// +kubebuilder:validation:Optional
	MemoryShares *float64 `json:"memoryShares,omitempty" tf:"memory_shares,omitempty"`

	// The name of the vApp container.
	// The name of the vApp container.
	// +kubebuilder:validation:Required
	Name *string `json:"name" tf:"name,omitempty"`

	// The managed object ID of
	// the vApp container's parent folder.
	// The ID of the parent VM folder.
	// +kubebuilder:validation:Optional
	ParentFolderID *string `json:"parentFolderId,omitempty" tf:"parent_folder_id,omitempty"`

	// The managed object ID
	// of the parent resource pool. This can be the root resource pool for a cluster
	// or standalone host, or a resource pool itself. When moving a vApp container
	// from one parent resource pool to another, both must share a common root
	// resource pool or the move will fail.
	// The managed object ID of the parent resource pool or the compute resource the vApp container is in.
	// +kubebuilder:validation:Required
	ParentResourcePoolID *string `json:"parentResourcePoolId" tf:"parent_resource_pool_id,omitempty"`

	// The IDs of any tags to attach to this resource. See
	// here for a reference on how to apply tags.
	// A list of tag IDs to apply to this object.
	// +kubebuilder:validation:Optional
	Tags []*string `json:"tags,omitempty" tf:"tags,omitempty"`
}

func (*ContainerParameters) DeepCopy

func (in *ContainerParameters) DeepCopy() *ContainerParameters

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerParameters.

func (*ContainerParameters) DeepCopyInto

func (in *ContainerParameters) DeepCopyInto(out *ContainerParameters)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ContainerSpec

type ContainerSpec struct {
	v1.ResourceSpec `json:",inline"`
	ForProvider     ContainerParameters `json:"forProvider"`
}

ContainerSpec defines the desired state of Container

func (*ContainerSpec) DeepCopy

func (in *ContainerSpec) DeepCopy() *ContainerSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerSpec.

func (*ContainerSpec) DeepCopyInto

func (in *ContainerSpec) DeepCopyInto(out *ContainerSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type ContainerStatus

type ContainerStatus struct {
	v1.ResourceStatus `json:",inline"`
	AtProvider        ContainerObservation `json:"atProvider,omitempty"`
}

ContainerStatus defines the observed state of Container.

func (*ContainerStatus) DeepCopy

func (in *ContainerStatus) DeepCopy() *ContainerStatus

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ContainerStatus.

func (*ContainerStatus) DeepCopyInto

func (in *ContainerStatus) DeepCopyInto(out *ContainerStatus)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to