Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=vappentity.vsphere.upbound.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type Entity
- func (in *Entity) DeepCopy() *Entity
- func (in *Entity) DeepCopyInto(out *Entity)
- func (in *Entity) DeepCopyObject() runtime.Object
- func (mg *Entity) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *Entity) GetConnectionDetailsMapping() map[string]string
- func (mg *Entity) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *Entity) GetID() string
- func (tr *Entity) GetObservation() (map[string]any, error)
- func (tr *Entity) GetParameters() (map[string]any, error)
- func (mg *Entity) GetProviderConfigReference() *xpv1.Reference
- func (mg *Entity) GetProviderReference() *xpv1.Reference
- func (mg *Entity) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *Entity) GetTerraformResourceType() string
- func (tr *Entity) GetTerraformSchemaVersion() int
- func (mg *Entity) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *Entity) LateInitialize(attrs []byte) (bool, error)
- func (mg *Entity) SetConditions(c ...xpv1.Condition)
- func (mg *Entity) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (tr *Entity) SetObservation(obs map[string]any) error
- func (tr *Entity) SetParameters(params map[string]any) error
- func (mg *Entity) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *Entity) SetProviderReference(r *xpv1.Reference)
- func (mg *Entity) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *Entity) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type EntityList
- type EntityObservation
- type EntityParameters
- type EntitySpec
- type EntityStatus
Constants ¶
const ( CRDGroup = "vappentity.vsphere.upbound.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( Entity_Kind = "Entity" Entity_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: Entity_Kind}.String() Entity_KindAPIVersion = Entity_Kind + "." + CRDGroupVersion.String() Entity_GroupVersionKind = CRDGroupVersion.WithKind(Entity_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Entity ¶
type Entity struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec EntitySpec `json:"spec"`
Status EntityStatus `json:"status,omitempty"`
}
Entity is the Schema for the Entitys API. Provides a vSphere vApp entity resource. This can be used to describe the behavior of an entity (virtual machine or sub-vApp container) in a vApp container. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,vsphere}
func (*Entity) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Entity.
func (*Entity) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Entity) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Entity) GetCondition ¶
func (mg *Entity) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this Entity.
func (*Entity) GetConnectionDetailsMapping ¶
GetConnectionDetailsMapping for this Entity
func (*Entity) GetDeletionPolicy ¶
func (mg *Entity) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this Entity.
func (*Entity) GetObservation ¶
GetObservation of this Entity
func (*Entity) GetParameters ¶
GetParameters of this Entity
func (*Entity) GetProviderConfigReference ¶
GetProviderConfigReference of this Entity.
func (*Entity) GetProviderReference ¶
GetProviderReference of this Entity. Deprecated: Use GetProviderConfigReference.
func (*Entity) GetPublishConnectionDetailsTo ¶
func (mg *Entity) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this Entity.
func (*Entity) GetTerraformResourceType ¶
GetTerraformResourceType returns Terraform resource type for this Entity
func (*Entity) GetTerraformSchemaVersion ¶
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*Entity) GetWriteConnectionSecretToReference ¶
func (mg *Entity) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this Entity.
func (*Entity) LateInitialize ¶
LateInitialize this Entity using its observed tfState. returns True if there are any spec changes for the resource.
func (*Entity) SetConditions ¶
SetConditions of this Entity.
func (*Entity) SetDeletionPolicy ¶
func (mg *Entity) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this Entity.
func (*Entity) SetObservation ¶
SetObservation for this Entity
func (*Entity) SetParameters ¶
SetParameters for this Entity
func (*Entity) SetProviderConfigReference ¶
SetProviderConfigReference of this Entity.
func (*Entity) SetProviderReference ¶
SetProviderReference of this Entity. Deprecated: Use SetProviderConfigReference.
func (*Entity) SetPublishConnectionDetailsTo ¶
func (mg *Entity) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this Entity.
func (*Entity) SetWriteConnectionSecretToReference ¶
func (mg *Entity) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this Entity.
type EntityList ¶
type EntityList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Entity `json:"items"`
}
EntityList contains a list of Entitys
func (*EntityList) DeepCopy ¶
func (in *EntityList) DeepCopy() *EntityList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EntityList.
func (*EntityList) DeepCopyInto ¶
func (in *EntityList) DeepCopyInto(out *EntityList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EntityList) DeepCopyObject ¶
func (in *EntityList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*EntityList) GetItems ¶
func (l *EntityList) GetItems() []resource.Managed
GetItems of this EntityList.
type EntityObservation ¶
type EntityObservation struct {
ID *string `json:"id,omitempty" tf:"id,omitempty"`
}
func (*EntityObservation) DeepCopy ¶
func (in *EntityObservation) DeepCopy() *EntityObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EntityObservation.
func (*EntityObservation) DeepCopyInto ¶
func (in *EntityObservation) DeepCopyInto(out *EntityObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EntityParameters ¶
type EntityParameters struct {
// [Managed object ID|docs-about-morefs] of the vApp
// container the entity is a member of.
// Managed object ID of the vApp container the entity is a member of.
// +kubebuilder:validation:Required
ContainerID *string `json:"containerId" tf:"container_id,omitempty"`
// A list of custom attributes to set on this resource.
// +kubebuilder:validation:Optional
CustomAttributes map[string]*string `json:"customAttributes,omitempty" tf:"custom_attributes,omitempty"`
// How to start the entity. Valid settings are none
// or powerOn. If set to none, then the entity does not participate in auto-start.
// Default: powerOn
// How to start the entity. Valid settings are none or powerOn. If set to none, then the entity does not participate in auto-start.
// +kubebuilder:validation:Optional
StartAction *string `json:"startAction,omitempty" tf:"start_action,omitempty"`
// Delay in seconds before continuing with the next
// entity in the order of entities to be started. Default: 120
// Delay in seconds before continuing with the next entity in the order of entities to be started.
// +kubebuilder:validation:Optional
StartDelay *float64 `json:"startDelay,omitempty" tf:"start_delay,omitempty"`
// Order to start and stop target in vApp. Default: 1
// Order to start and stop target in vApp.
// +kubebuilder:validation:Optional
StartOrder *float64 `json:"startOrder,omitempty" tf:"start_order,omitempty"`
// Defines the stop action for the entity. Can be set
// to none, powerOff, guestShutdown, or suspend. If set to none, then the entity
// does not participate in auto-stop. Default: powerOff
// Defines the stop action for the entity. Can be set to none, powerOff, guestShutdown, or suspend. If set to none, then the entity does not participate in auto-stop.
// +kubebuilder:validation:Optional
StopAction *string `json:"stopAction,omitempty" tf:"stop_action,omitempty"`
// Delay in seconds before continuing with the next
// entity in the order sequence. This is only used if the stopAction is
// guestShutdown. Default: 120
// Delay in seconds before continuing with the next entity in the order of entities to be stopped.
// +kubebuilder:validation:Optional
StopDelay *float64 `json:"stopDelay,omitempty" tf:"stop_delay,omitempty"`
// A list of tag IDs to apply to this object.
// +kubebuilder:validation:Optional
Tags []*string `json:"tags,omitempty" tf:"tags,omitempty"`
// [Managed object ID|docs-about-morefs] of the entity
// to power on or power off. This can be a virtual machine or a vApp.
// Managed object ID of the entity to power on or power off. This can be a virtual machine or a vApp.
// +kubebuilder:validation:Required
TargetID *string `json:"targetId" tf:"target_id,omitempty"`
// Determines if the VM should be marked as being
// started when VMware Tools are ready instead of waiting for start_delay. This
// property has no effect for vApps. Default: false
// Determines if the VM should be marked as being started when VMware Tools are ready instead of waiting for start_delay. This property has no effect for vApps.
// +kubebuilder:validation:Optional
WaitForGuest *bool `json:"waitForGuest,omitempty" tf:"wait_for_guest,omitempty"`
}
func (*EntityParameters) DeepCopy ¶
func (in *EntityParameters) DeepCopy() *EntityParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EntityParameters.
func (*EntityParameters) DeepCopyInto ¶
func (in *EntityParameters) DeepCopyInto(out *EntityParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EntitySpec ¶
type EntitySpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider EntityParameters `json:"forProvider"`
}
EntitySpec defines the desired state of Entity
func (*EntitySpec) DeepCopy ¶
func (in *EntitySpec) DeepCopy() *EntitySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EntitySpec.
func (*EntitySpec) DeepCopyInto ¶
func (in *EntitySpec) DeepCopyInto(out *EntitySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EntityStatus ¶
type EntityStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider EntityObservation `json:"atProvider,omitempty"`
}
EntityStatus defines the observed state of Entity.
func (*EntityStatus) DeepCopy ¶
func (in *EntityStatus) DeepCopy() *EntityStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EntityStatus.
func (*EntityStatus) DeepCopyInto ¶
func (in *EntityStatus) DeepCopyInto(out *EntityStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.