Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=computeclustervmaffinityrule.vsphere.upbound.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type ClusterVMAffinityRule
- func (in *ClusterVMAffinityRule) DeepCopy() *ClusterVMAffinityRule
- func (in *ClusterVMAffinityRule) DeepCopyInto(out *ClusterVMAffinityRule)
- func (in *ClusterVMAffinityRule) DeepCopyObject() runtime.Object
- func (mg *ClusterVMAffinityRule) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *ClusterVMAffinityRule) GetConnectionDetailsMapping() map[string]string
- func (mg *ClusterVMAffinityRule) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *ClusterVMAffinityRule) GetID() string
- func (tr *ClusterVMAffinityRule) GetObservation() (map[string]any, error)
- func (tr *ClusterVMAffinityRule) GetParameters() (map[string]any, error)
- func (mg *ClusterVMAffinityRule) GetProviderConfigReference() *xpv1.Reference
- func (mg *ClusterVMAffinityRule) GetProviderReference() *xpv1.Reference
- func (mg *ClusterVMAffinityRule) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *ClusterVMAffinityRule) GetTerraformResourceType() string
- func (tr *ClusterVMAffinityRule) GetTerraformSchemaVersion() int
- func (mg *ClusterVMAffinityRule) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *ClusterVMAffinityRule) LateInitialize(attrs []byte) (bool, error)
- func (mg *ClusterVMAffinityRule) SetConditions(c ...xpv1.Condition)
- func (mg *ClusterVMAffinityRule) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (tr *ClusterVMAffinityRule) SetObservation(obs map[string]any) error
- func (tr *ClusterVMAffinityRule) SetParameters(params map[string]any) error
- func (mg *ClusterVMAffinityRule) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *ClusterVMAffinityRule) SetProviderReference(r *xpv1.Reference)
- func (mg *ClusterVMAffinityRule) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *ClusterVMAffinityRule) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type ClusterVMAffinityRuleList
- type ClusterVMAffinityRuleObservation
- type ClusterVMAffinityRuleParameters
- type ClusterVMAffinityRuleSpec
- type ClusterVMAffinityRuleStatus
Constants ¶
const ( CRDGroup = "computeclustervmaffinityrule.vsphere.upbound.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( ClusterVMAffinityRule_Kind = "ClusterVMAffinityRule" ClusterVMAffinityRule_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: ClusterVMAffinityRule_Kind}.String() ClusterVMAffinityRule_KindAPIVersion = ClusterVMAffinityRule_Kind + "." + CRDGroupVersion.String() ClusterVMAffinityRule_GroupVersionKind = CRDGroupVersion.WithKind(ClusterVMAffinityRule_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type ClusterVMAffinityRule ¶
type ClusterVMAffinityRule struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec ClusterVMAffinityRuleSpec `json:"spec"`
Status ClusterVMAffinityRuleStatus `json:"status,omitempty"`
}
ClusterVMAffinityRule is the Schema for the ClusterVMAffinityRules API. Provides the VMware vSphere Distributed Resource Scheduler affinity rule resource. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,vsphere}
func (*ClusterVMAffinityRule) DeepCopy ¶
func (in *ClusterVMAffinityRule) DeepCopy() *ClusterVMAffinityRule
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterVMAffinityRule.
func (*ClusterVMAffinityRule) DeepCopyInto ¶
func (in *ClusterVMAffinityRule) DeepCopyInto(out *ClusterVMAffinityRule)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ClusterVMAffinityRule) DeepCopyObject ¶
func (in *ClusterVMAffinityRule) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ClusterVMAffinityRule) GetCondition ¶
func (mg *ClusterVMAffinityRule) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this ClusterVMAffinityRule.
func (*ClusterVMAffinityRule) GetConnectionDetailsMapping ¶
func (tr *ClusterVMAffinityRule) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this ClusterVMAffinityRule
func (*ClusterVMAffinityRule) GetDeletionPolicy ¶
func (mg *ClusterVMAffinityRule) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this ClusterVMAffinityRule.
func (*ClusterVMAffinityRule) GetID ¶
func (tr *ClusterVMAffinityRule) GetID() string
GetID returns ID of underlying Terraform resource of this ClusterVMAffinityRule
func (*ClusterVMAffinityRule) GetObservation ¶
func (tr *ClusterVMAffinityRule) GetObservation() (map[string]any, error)
GetObservation of this ClusterVMAffinityRule
func (*ClusterVMAffinityRule) GetParameters ¶
func (tr *ClusterVMAffinityRule) GetParameters() (map[string]any, error)
GetParameters of this ClusterVMAffinityRule
func (*ClusterVMAffinityRule) GetProviderConfigReference ¶
func (mg *ClusterVMAffinityRule) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this ClusterVMAffinityRule.
func (*ClusterVMAffinityRule) GetProviderReference ¶
func (mg *ClusterVMAffinityRule) GetProviderReference() *xpv1.Reference
GetProviderReference of this ClusterVMAffinityRule. Deprecated: Use GetProviderConfigReference.
func (*ClusterVMAffinityRule) GetPublishConnectionDetailsTo ¶
func (mg *ClusterVMAffinityRule) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this ClusterVMAffinityRule.
func (*ClusterVMAffinityRule) GetTerraformResourceType ¶
func (mg *ClusterVMAffinityRule) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this ClusterVMAffinityRule
func (*ClusterVMAffinityRule) GetTerraformSchemaVersion ¶
func (tr *ClusterVMAffinityRule) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*ClusterVMAffinityRule) GetWriteConnectionSecretToReference ¶
func (mg *ClusterVMAffinityRule) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this ClusterVMAffinityRule.
func (*ClusterVMAffinityRule) LateInitialize ¶
func (tr *ClusterVMAffinityRule) LateInitialize(attrs []byte) (bool, error)
LateInitialize this ClusterVMAffinityRule using its observed tfState. returns True if there are any spec changes for the resource.
func (*ClusterVMAffinityRule) SetConditions ¶
func (mg *ClusterVMAffinityRule) SetConditions(c ...xpv1.Condition)
SetConditions of this ClusterVMAffinityRule.
func (*ClusterVMAffinityRule) SetDeletionPolicy ¶
func (mg *ClusterVMAffinityRule) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this ClusterVMAffinityRule.
func (*ClusterVMAffinityRule) SetObservation ¶
func (tr *ClusterVMAffinityRule) SetObservation(obs map[string]any) error
SetObservation for this ClusterVMAffinityRule
func (*ClusterVMAffinityRule) SetParameters ¶
func (tr *ClusterVMAffinityRule) SetParameters(params map[string]any) error
SetParameters for this ClusterVMAffinityRule
func (*ClusterVMAffinityRule) SetProviderConfigReference ¶
func (mg *ClusterVMAffinityRule) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this ClusterVMAffinityRule.
func (*ClusterVMAffinityRule) SetProviderReference ¶
func (mg *ClusterVMAffinityRule) SetProviderReference(r *xpv1.Reference)
SetProviderReference of this ClusterVMAffinityRule. Deprecated: Use SetProviderConfigReference.
func (*ClusterVMAffinityRule) SetPublishConnectionDetailsTo ¶
func (mg *ClusterVMAffinityRule) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this ClusterVMAffinityRule.
func (*ClusterVMAffinityRule) SetWriteConnectionSecretToReference ¶
func (mg *ClusterVMAffinityRule) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this ClusterVMAffinityRule.
type ClusterVMAffinityRuleList ¶
type ClusterVMAffinityRuleList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []ClusterVMAffinityRule `json:"items"`
}
ClusterVMAffinityRuleList contains a list of ClusterVMAffinityRules
func (*ClusterVMAffinityRuleList) DeepCopy ¶
func (in *ClusterVMAffinityRuleList) DeepCopy() *ClusterVMAffinityRuleList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterVMAffinityRuleList.
func (*ClusterVMAffinityRuleList) DeepCopyInto ¶
func (in *ClusterVMAffinityRuleList) DeepCopyInto(out *ClusterVMAffinityRuleList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ClusterVMAffinityRuleList) DeepCopyObject ¶
func (in *ClusterVMAffinityRuleList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*ClusterVMAffinityRuleList) GetItems ¶
func (l *ClusterVMAffinityRuleList) GetItems() []resource.Managed
GetItems of this ClusterVMAffinityRuleList.
type ClusterVMAffinityRuleObservation ¶
type ClusterVMAffinityRuleObservation struct {
ID *string `json:"id,omitempty" tf:"id,omitempty"`
}
func (*ClusterVMAffinityRuleObservation) DeepCopy ¶
func (in *ClusterVMAffinityRuleObservation) DeepCopy() *ClusterVMAffinityRuleObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterVMAffinityRuleObservation.
func (*ClusterVMAffinityRuleObservation) DeepCopyInto ¶
func (in *ClusterVMAffinityRuleObservation) DeepCopyInto(out *ClusterVMAffinityRuleObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterVMAffinityRuleParameters ¶
type ClusterVMAffinityRuleParameters struct {
// The managed object reference
// ID of the cluster to put the group in. Forces a new
// resource if changed.
// The managed object ID of the cluster.
// +kubebuilder:validation:Required
ComputeClusterID *string `json:"computeClusterId" tf:"compute_cluster_id,omitempty"`
// Enable this rule in the cluster. Default: true.
// Enable this rule in the cluster.
// +kubebuilder:validation:Optional
Enabled *bool `json:"enabled,omitempty" tf:"enabled,omitempty"`
// When this value is true, prevents any virtual
// machine operations that may violate this rule. Default: false.
// When true, prevents any virtual machine operations that may violate this rule.
// +kubebuilder:validation:Optional
Mandatory *bool `json:"mandatory,omitempty" tf:"mandatory,omitempty"`
// The name of the rule. This must be unique in the cluster.
// The unique name of the virtual machine group in the cluster.
// +kubebuilder:validation:Required
Name *string `json:"name" tf:"name,omitempty"`
// The UUIDs of the virtual machines to run
// on the same host together.
// The UUIDs of the virtual machines to run on the same host together.
// +kubebuilder:validation:Required
VirtualMachineIds []*string `json:"virtualMachineIds" tf:"virtual_machine_ids,omitempty"`
}
func (*ClusterVMAffinityRuleParameters) DeepCopy ¶
func (in *ClusterVMAffinityRuleParameters) DeepCopy() *ClusterVMAffinityRuleParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterVMAffinityRuleParameters.
func (*ClusterVMAffinityRuleParameters) DeepCopyInto ¶
func (in *ClusterVMAffinityRuleParameters) DeepCopyInto(out *ClusterVMAffinityRuleParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterVMAffinityRuleSpec ¶
type ClusterVMAffinityRuleSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider ClusterVMAffinityRuleParameters `json:"forProvider"`
}
ClusterVMAffinityRuleSpec defines the desired state of ClusterVMAffinityRule
func (*ClusterVMAffinityRuleSpec) DeepCopy ¶
func (in *ClusterVMAffinityRuleSpec) DeepCopy() *ClusterVMAffinityRuleSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterVMAffinityRuleSpec.
func (*ClusterVMAffinityRuleSpec) DeepCopyInto ¶
func (in *ClusterVMAffinityRuleSpec) DeepCopyInto(out *ClusterVMAffinityRuleSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ClusterVMAffinityRuleStatus ¶
type ClusterVMAffinityRuleStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider ClusterVMAffinityRuleObservation `json:"atProvider,omitempty"`
}
ClusterVMAffinityRuleStatus defines the observed state of ClusterVMAffinityRule.
func (*ClusterVMAffinityRuleStatus) DeepCopy ¶
func (in *ClusterVMAffinityRuleStatus) DeepCopy() *ClusterVMAffinityRuleStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ClusterVMAffinityRuleStatus.
func (*ClusterVMAffinityRuleStatus) DeepCopyInto ¶
func (in *ClusterVMAffinityRuleStatus) DeepCopyInto(out *ClusterVMAffinityRuleStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.