Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=contentlibraryitem.vsphere.upbound.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type LibraryItem
- func (in *LibraryItem) DeepCopy() *LibraryItem
- func (in *LibraryItem) DeepCopyInto(out *LibraryItem)
- func (in *LibraryItem) DeepCopyObject() runtime.Object
- func (mg *LibraryItem) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *LibraryItem) GetConnectionDetailsMapping() map[string]string
- func (mg *LibraryItem) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *LibraryItem) GetID() string
- func (tr *LibraryItem) GetObservation() (map[string]any, error)
- func (tr *LibraryItem) GetParameters() (map[string]any, error)
- func (mg *LibraryItem) GetProviderConfigReference() *xpv1.Reference
- func (mg *LibraryItem) GetProviderReference() *xpv1.Reference
- func (mg *LibraryItem) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *LibraryItem) GetTerraformResourceType() string
- func (tr *LibraryItem) GetTerraformSchemaVersion() int
- func (mg *LibraryItem) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *LibraryItem) LateInitialize(attrs []byte) (bool, error)
- func (mg *LibraryItem) SetConditions(c ...xpv1.Condition)
- func (mg *LibraryItem) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (tr *LibraryItem) SetObservation(obs map[string]any) error
- func (tr *LibraryItem) SetParameters(params map[string]any) error
- func (mg *LibraryItem) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *LibraryItem) SetProviderReference(r *xpv1.Reference)
- func (mg *LibraryItem) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *LibraryItem) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type LibraryItemList
- type LibraryItemObservation
- type LibraryItemParameters
- type LibraryItemSpec
- type LibraryItemStatus
Constants ¶
const ( CRDGroup = "contentlibraryitem.vsphere.upbound.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( LibraryItem_Kind = "LibraryItem" LibraryItem_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: LibraryItem_Kind}.String() LibraryItem_KindAPIVersion = LibraryItem_Kind + "." + CRDGroupVersion.String() LibraryItem_GroupVersionKind = CRDGroupVersion.WithKind(LibraryItem_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type LibraryItem ¶
type LibraryItem struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec LibraryItemSpec `json:"spec"`
Status LibraryItemStatus `json:"status,omitempty"`
}
LibraryItem is the Schema for the LibraryItems API. Creates an item in a vSphere content library. Each item can contain multiple files. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,vsphere}
func (*LibraryItem) DeepCopy ¶
func (in *LibraryItem) DeepCopy() *LibraryItem
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LibraryItem.
func (*LibraryItem) DeepCopyInto ¶
func (in *LibraryItem) DeepCopyInto(out *LibraryItem)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LibraryItem) DeepCopyObject ¶
func (in *LibraryItem) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*LibraryItem) GetCondition ¶
func (mg *LibraryItem) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this LibraryItem.
func (*LibraryItem) GetConnectionDetailsMapping ¶
func (tr *LibraryItem) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this LibraryItem
func (*LibraryItem) GetDeletionPolicy ¶
func (mg *LibraryItem) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this LibraryItem.
func (*LibraryItem) GetID ¶
func (tr *LibraryItem) GetID() string
GetID returns ID of underlying Terraform resource of this LibraryItem
func (*LibraryItem) GetObservation ¶
func (tr *LibraryItem) GetObservation() (map[string]any, error)
GetObservation of this LibraryItem
func (*LibraryItem) GetParameters ¶
func (tr *LibraryItem) GetParameters() (map[string]any, error)
GetParameters of this LibraryItem
func (*LibraryItem) GetProviderConfigReference ¶
func (mg *LibraryItem) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this LibraryItem.
func (*LibraryItem) GetProviderReference ¶
func (mg *LibraryItem) GetProviderReference() *xpv1.Reference
GetProviderReference of this LibraryItem. Deprecated: Use GetProviderConfigReference.
func (*LibraryItem) GetPublishConnectionDetailsTo ¶
func (mg *LibraryItem) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this LibraryItem.
func (*LibraryItem) GetTerraformResourceType ¶
func (mg *LibraryItem) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this LibraryItem
func (*LibraryItem) GetTerraformSchemaVersion ¶
func (tr *LibraryItem) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*LibraryItem) GetWriteConnectionSecretToReference ¶
func (mg *LibraryItem) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this LibraryItem.
func (*LibraryItem) LateInitialize ¶
func (tr *LibraryItem) LateInitialize(attrs []byte) (bool, error)
LateInitialize this LibraryItem using its observed tfState. returns True if there are any spec changes for the resource.
func (*LibraryItem) SetConditions ¶
func (mg *LibraryItem) SetConditions(c ...xpv1.Condition)
SetConditions of this LibraryItem.
func (*LibraryItem) SetDeletionPolicy ¶
func (mg *LibraryItem) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this LibraryItem.
func (*LibraryItem) SetObservation ¶
func (tr *LibraryItem) SetObservation(obs map[string]any) error
SetObservation for this LibraryItem
func (*LibraryItem) SetParameters ¶
func (tr *LibraryItem) SetParameters(params map[string]any) error
SetParameters for this LibraryItem
func (*LibraryItem) SetProviderConfigReference ¶
func (mg *LibraryItem) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this LibraryItem.
func (*LibraryItem) SetProviderReference ¶
func (mg *LibraryItem) SetProviderReference(r *xpv1.Reference)
SetProviderReference of this LibraryItem. Deprecated: Use SetProviderConfigReference.
func (*LibraryItem) SetPublishConnectionDetailsTo ¶
func (mg *LibraryItem) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this LibraryItem.
func (*LibraryItem) SetWriteConnectionSecretToReference ¶
func (mg *LibraryItem) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this LibraryItem.
type LibraryItemList ¶
type LibraryItemList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []LibraryItem `json:"items"`
}
LibraryItemList contains a list of LibraryItems
func (*LibraryItemList) DeepCopy ¶
func (in *LibraryItemList) DeepCopy() *LibraryItemList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LibraryItemList.
func (*LibraryItemList) DeepCopyInto ¶
func (in *LibraryItemList) DeepCopyInto(out *LibraryItemList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*LibraryItemList) DeepCopyObject ¶
func (in *LibraryItemList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*LibraryItemList) GetItems ¶
func (l *LibraryItemList) GetItems() []resource.Managed
GetItems of this LibraryItemList.
type LibraryItemObservation ¶
type LibraryItemObservation struct {
ID *string `json:"id,omitempty" tf:"id,omitempty"`
}
func (*LibraryItemObservation) DeepCopy ¶
func (in *LibraryItemObservation) DeepCopy() *LibraryItemObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LibraryItemObservation.
func (*LibraryItemObservation) DeepCopyInto ¶
func (in *LibraryItemObservation) DeepCopyInto(out *LibraryItemObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LibraryItemParameters ¶
type LibraryItemParameters struct {
// A description for the content library item.
// Optional description of the content library item.
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
// File to import as the content library item.
// ID of source VM of content library item.
// +kubebuilder:validation:Optional
FileURL *string `json:"fileUrl,omitempty" tf:"file_url,omitempty"`
// The ID of the content library in which to create the item.
// ID of the content library to contain item
// +kubebuilder:validation:Required
LibraryID *string `json:"libraryId" tf:"library_id,omitempty"`
// The name of the item to be created in the content library.
// The name of the content library item.
// +kubebuilder:validation:Required
Name *string `json:"name" tf:"name,omitempty"`
// Virtual machine UUID to clone to content library.
// The managed object ID of an existing VM to be cloned to the content library.
// +kubebuilder:validation:Optional
SourceUUID *string `json:"sourceUuid,omitempty" tf:"source_uuid,omitempty"`
// Type of content library item.
// One of "ovf", "iso", or "vm-template". Default: ovf.
// Type of content library item.
// +kubebuilder:validation:Optional
Type *string `json:"type,omitempty" tf:"type,omitempty"`
}
func (*LibraryItemParameters) DeepCopy ¶
func (in *LibraryItemParameters) DeepCopy() *LibraryItemParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LibraryItemParameters.
func (*LibraryItemParameters) DeepCopyInto ¶
func (in *LibraryItemParameters) DeepCopyInto(out *LibraryItemParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LibraryItemSpec ¶
type LibraryItemSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider LibraryItemParameters `json:"forProvider"`
}
LibraryItemSpec defines the desired state of LibraryItem
func (*LibraryItemSpec) DeepCopy ¶
func (in *LibraryItemSpec) DeepCopy() *LibraryItemSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LibraryItemSpec.
func (*LibraryItemSpec) DeepCopyInto ¶
func (in *LibraryItemSpec) DeepCopyInto(out *LibraryItemSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type LibraryItemStatus ¶
type LibraryItemStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider LibraryItemObservation `json:"atProvider,omitempty"`
}
LibraryItemStatus defines the observed state of LibraryItem.
func (*LibraryItemStatus) DeepCopy ¶
func (in *LibraryItemStatus) DeepCopy() *LibraryItemStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new LibraryItemStatus.
func (*LibraryItemStatus) DeepCopyInto ¶
func (in *LibraryItemStatus) DeepCopyInto(out *LibraryItemStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.