Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=datacenter.vsphere.upbound.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type Datacenter
- func (in *Datacenter) DeepCopy() *Datacenter
- func (in *Datacenter) DeepCopyInto(out *Datacenter)
- func (in *Datacenter) DeepCopyObject() runtime.Object
- func (mg *Datacenter) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *Datacenter) GetConnectionDetailsMapping() map[string]string
- func (mg *Datacenter) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *Datacenter) GetID() string
- func (tr *Datacenter) GetObservation() (map[string]any, error)
- func (tr *Datacenter) GetParameters() (map[string]any, error)
- func (mg *Datacenter) GetProviderConfigReference() *xpv1.Reference
- func (mg *Datacenter) GetProviderReference() *xpv1.Reference
- func (mg *Datacenter) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *Datacenter) GetTerraformResourceType() string
- func (tr *Datacenter) GetTerraformSchemaVersion() int
- func (mg *Datacenter) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *Datacenter) LateInitialize(attrs []byte) (bool, error)
- func (mg *Datacenter) SetConditions(c ...xpv1.Condition)
- func (mg *Datacenter) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (tr *Datacenter) SetObservation(obs map[string]any) error
- func (tr *Datacenter) SetParameters(params map[string]any) error
- func (mg *Datacenter) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *Datacenter) SetProviderReference(r *xpv1.Reference)
- func (mg *Datacenter) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *Datacenter) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type DatacenterList
- type DatacenterObservation
- type DatacenterParameters
- type DatacenterSpec
- type DatacenterStatus
Constants ¶
const ( CRDGroup = "datacenter.vsphere.upbound.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( Datacenter_Kind = "Datacenter" Datacenter_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: Datacenter_Kind}.String() Datacenter_KindAPIVersion = Datacenter_Kind + "." + CRDGroupVersion.String() Datacenter_GroupVersionKind = CRDGroupVersion.WithKind(Datacenter_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Datacenter ¶
type Datacenter struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec DatacenterSpec `json:"spec"`
Status DatacenterStatus `json:"status,omitempty"`
}
Datacenter is the Schema for the Datacenters API. Provides a VMware vSphere datacenter resource. This can be used as the primary container of inventory objects such as hosts and virtual machines. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,vsphere}
func (*Datacenter) DeepCopy ¶
func (in *Datacenter) DeepCopy() *Datacenter
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Datacenter.
func (*Datacenter) DeepCopyInto ¶
func (in *Datacenter) DeepCopyInto(out *Datacenter)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Datacenter) DeepCopyObject ¶
func (in *Datacenter) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Datacenter) GetCondition ¶
func (mg *Datacenter) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this Datacenter.
func (*Datacenter) GetConnectionDetailsMapping ¶
func (tr *Datacenter) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this Datacenter
func (*Datacenter) GetDeletionPolicy ¶
func (mg *Datacenter) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this Datacenter.
func (*Datacenter) GetID ¶
func (tr *Datacenter) GetID() string
GetID returns ID of underlying Terraform resource of this Datacenter
func (*Datacenter) GetObservation ¶
func (tr *Datacenter) GetObservation() (map[string]any, error)
GetObservation of this Datacenter
func (*Datacenter) GetParameters ¶
func (tr *Datacenter) GetParameters() (map[string]any, error)
GetParameters of this Datacenter
func (*Datacenter) GetProviderConfigReference ¶
func (mg *Datacenter) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this Datacenter.
func (*Datacenter) GetProviderReference ¶
func (mg *Datacenter) GetProviderReference() *xpv1.Reference
GetProviderReference of this Datacenter. Deprecated: Use GetProviderConfigReference.
func (*Datacenter) GetPublishConnectionDetailsTo ¶
func (mg *Datacenter) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this Datacenter.
func (*Datacenter) GetTerraformResourceType ¶
func (mg *Datacenter) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this Datacenter
func (*Datacenter) GetTerraformSchemaVersion ¶
func (tr *Datacenter) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*Datacenter) GetWriteConnectionSecretToReference ¶
func (mg *Datacenter) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this Datacenter.
func (*Datacenter) LateInitialize ¶
func (tr *Datacenter) LateInitialize(attrs []byte) (bool, error)
LateInitialize this Datacenter using its observed tfState. returns True if there are any spec changes for the resource.
func (*Datacenter) SetConditions ¶
func (mg *Datacenter) SetConditions(c ...xpv1.Condition)
SetConditions of this Datacenter.
func (*Datacenter) SetDeletionPolicy ¶
func (mg *Datacenter) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this Datacenter.
func (*Datacenter) SetObservation ¶
func (tr *Datacenter) SetObservation(obs map[string]any) error
SetObservation for this Datacenter
func (*Datacenter) SetParameters ¶
func (tr *Datacenter) SetParameters(params map[string]any) error
SetParameters for this Datacenter
func (*Datacenter) SetProviderConfigReference ¶
func (mg *Datacenter) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this Datacenter.
func (*Datacenter) SetProviderReference ¶
func (mg *Datacenter) SetProviderReference(r *xpv1.Reference)
SetProviderReference of this Datacenter. Deprecated: Use SetProviderConfigReference.
func (*Datacenter) SetPublishConnectionDetailsTo ¶
func (mg *Datacenter) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this Datacenter.
func (*Datacenter) SetWriteConnectionSecretToReference ¶
func (mg *Datacenter) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this Datacenter.
type DatacenterList ¶
type DatacenterList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Datacenter `json:"items"`
}
DatacenterList contains a list of Datacenters
func (*DatacenterList) DeepCopy ¶
func (in *DatacenterList) DeepCopy() *DatacenterList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatacenterList.
func (*DatacenterList) DeepCopyInto ¶
func (in *DatacenterList) DeepCopyInto(out *DatacenterList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*DatacenterList) DeepCopyObject ¶
func (in *DatacenterList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*DatacenterList) GetItems ¶
func (l *DatacenterList) GetItems() []resource.Managed
GetItems of this DatacenterList.
type DatacenterObservation ¶
type DatacenterObservation struct {
// The name of this datacenter. This will be changed to the managed
// object ID in v2.0.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
// Managed object ID of this datacenter.
// Managed object ID of the datacenter.
Moid *string `json:"moid,omitempty" tf:"moid,omitempty"`
}
func (*DatacenterObservation) DeepCopy ¶
func (in *DatacenterObservation) DeepCopy() *DatacenterObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatacenterObservation.
func (*DatacenterObservation) DeepCopyInto ¶
func (in *DatacenterObservation) DeepCopyInto(out *DatacenterObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DatacenterParameters ¶
type DatacenterParameters struct {
// Map of custom attribute ids to value
// strings to set for datacenter resource. See
// here for a reference on how to set values
// for custom attributes.
// A list of custom attributes to set on this resource.
// +kubebuilder:validation:Optional
CustomAttributes map[string]*string `json:"customAttributes,omitempty" tf:"custom_attributes,omitempty"`
// The folder where the datacenter should be created.
// Forces a new resource if changed.
// +kubebuilder:validation:Optional
Folder *string `json:"folder,omitempty" tf:"folder,omitempty"`
// The IDs of any tags to attach to this resource. See
// here for a reference on how to apply tags.
// A list of tag IDs to apply to this object.
// +kubebuilder:validation:Optional
Tags []*string `json:"tags,omitempty" tf:"tags,omitempty"`
}
func (*DatacenterParameters) DeepCopy ¶
func (in *DatacenterParameters) DeepCopy() *DatacenterParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatacenterParameters.
func (*DatacenterParameters) DeepCopyInto ¶
func (in *DatacenterParameters) DeepCopyInto(out *DatacenterParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DatacenterSpec ¶
type DatacenterSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider DatacenterParameters `json:"forProvider"`
}
DatacenterSpec defines the desired state of Datacenter
func (*DatacenterSpec) DeepCopy ¶
func (in *DatacenterSpec) DeepCopy() *DatacenterSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatacenterSpec.
func (*DatacenterSpec) DeepCopyInto ¶
func (in *DatacenterSpec) DeepCopyInto(out *DatacenterSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type DatacenterStatus ¶
type DatacenterStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider DatacenterObservation `json:"atProvider,omitempty"`
}
DatacenterStatus defines the observed state of Datacenter.
func (*DatacenterStatus) DeepCopy ¶
func (in *DatacenterStatus) DeepCopy() *DatacenterStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new DatacenterStatus.
func (*DatacenterStatus) DeepCopyInto ¶
func (in *DatacenterStatus) DeepCopyInto(out *DatacenterStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.