Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=havmoverride.vsphere.upbound.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type VMOverride
- func (in *VMOverride) DeepCopy() *VMOverride
- func (in *VMOverride) DeepCopyInto(out *VMOverride)
- func (in *VMOverride) DeepCopyObject() runtime.Object
- func (mg *VMOverride) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *VMOverride) GetConnectionDetailsMapping() map[string]string
- func (mg *VMOverride) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *VMOverride) GetID() string
- func (tr *VMOverride) GetObservation() (map[string]any, error)
- func (tr *VMOverride) GetParameters() (map[string]any, error)
- func (mg *VMOverride) GetProviderConfigReference() *xpv1.Reference
- func (mg *VMOverride) GetProviderReference() *xpv1.Reference
- func (mg *VMOverride) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *VMOverride) GetTerraformResourceType() string
- func (tr *VMOverride) GetTerraformSchemaVersion() int
- func (mg *VMOverride) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *VMOverride) LateInitialize(attrs []byte) (bool, error)
- func (mg *VMOverride) SetConditions(c ...xpv1.Condition)
- func (mg *VMOverride) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (tr *VMOverride) SetObservation(obs map[string]any) error
- func (tr *VMOverride) SetParameters(params map[string]any) error
- func (mg *VMOverride) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *VMOverride) SetProviderReference(r *xpv1.Reference)
- func (mg *VMOverride) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *VMOverride) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type VMOverrideList
- type VMOverrideObservation
- type VMOverrideParameters
- type VMOverrideSpec
- type VMOverrideStatus
Constants ¶
const ( CRDGroup = "havmoverride.vsphere.upbound.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( VMOverride_Kind = "VMOverride" VMOverride_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: VMOverride_Kind}.String() VMOverride_KindAPIVersion = VMOverride_Kind + "." + CRDGroupVersion.String() VMOverride_GroupVersionKind = CRDGroupVersion.WithKind(VMOverride_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type VMOverride ¶
type VMOverride struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec VMOverrideSpec `json:"spec"`
Status VMOverrideStatus `json:"status,omitempty"`
}
VMOverride is the Schema for the VMOverrides API. Provides a VMware vSphere HA virtual machine override resource. This can be used to override high availability settings in a cluster. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,vsphere}
func (*VMOverride) DeepCopy ¶
func (in *VMOverride) DeepCopy() *VMOverride
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VMOverride.
func (*VMOverride) DeepCopyInto ¶
func (in *VMOverride) DeepCopyInto(out *VMOverride)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VMOverride) DeepCopyObject ¶
func (in *VMOverride) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*VMOverride) GetCondition ¶
func (mg *VMOverride) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this VMOverride.
func (*VMOverride) GetConnectionDetailsMapping ¶
func (tr *VMOverride) GetConnectionDetailsMapping() map[string]string
GetConnectionDetailsMapping for this VMOverride
func (*VMOverride) GetDeletionPolicy ¶
func (mg *VMOverride) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this VMOverride.
func (*VMOverride) GetID ¶
func (tr *VMOverride) GetID() string
GetID returns ID of underlying Terraform resource of this VMOverride
func (*VMOverride) GetObservation ¶
func (tr *VMOverride) GetObservation() (map[string]any, error)
GetObservation of this VMOverride
func (*VMOverride) GetParameters ¶
func (tr *VMOverride) GetParameters() (map[string]any, error)
GetParameters of this VMOverride
func (*VMOverride) GetProviderConfigReference ¶
func (mg *VMOverride) GetProviderConfigReference() *xpv1.Reference
GetProviderConfigReference of this VMOverride.
func (*VMOverride) GetProviderReference ¶
func (mg *VMOverride) GetProviderReference() *xpv1.Reference
GetProviderReference of this VMOverride. Deprecated: Use GetProviderConfigReference.
func (*VMOverride) GetPublishConnectionDetailsTo ¶
func (mg *VMOverride) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this VMOverride.
func (*VMOverride) GetTerraformResourceType ¶
func (mg *VMOverride) GetTerraformResourceType() string
GetTerraformResourceType returns Terraform resource type for this VMOverride
func (*VMOverride) GetTerraformSchemaVersion ¶
func (tr *VMOverride) GetTerraformSchemaVersion() int
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*VMOverride) GetWriteConnectionSecretToReference ¶
func (mg *VMOverride) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this VMOverride.
func (*VMOverride) LateInitialize ¶
func (tr *VMOverride) LateInitialize(attrs []byte) (bool, error)
LateInitialize this VMOverride using its observed tfState. returns True if there are any spec changes for the resource.
func (*VMOverride) SetConditions ¶
func (mg *VMOverride) SetConditions(c ...xpv1.Condition)
SetConditions of this VMOverride.
func (*VMOverride) SetDeletionPolicy ¶
func (mg *VMOverride) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this VMOverride.
func (*VMOverride) SetObservation ¶
func (tr *VMOverride) SetObservation(obs map[string]any) error
SetObservation for this VMOverride
func (*VMOverride) SetParameters ¶
func (tr *VMOverride) SetParameters(params map[string]any) error
SetParameters for this VMOverride
func (*VMOverride) SetProviderConfigReference ¶
func (mg *VMOverride) SetProviderConfigReference(r *xpv1.Reference)
SetProviderConfigReference of this VMOverride.
func (*VMOverride) SetProviderReference ¶
func (mg *VMOverride) SetProviderReference(r *xpv1.Reference)
SetProviderReference of this VMOverride. Deprecated: Use SetProviderConfigReference.
func (*VMOverride) SetPublishConnectionDetailsTo ¶
func (mg *VMOverride) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this VMOverride.
func (*VMOverride) SetWriteConnectionSecretToReference ¶
func (mg *VMOverride) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this VMOverride.
type VMOverrideList ¶
type VMOverrideList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []VMOverride `json:"items"`
}
VMOverrideList contains a list of VMOverrides
func (*VMOverrideList) DeepCopy ¶
func (in *VMOverrideList) DeepCopy() *VMOverrideList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VMOverrideList.
func (*VMOverrideList) DeepCopyInto ¶
func (in *VMOverrideList) DeepCopyInto(out *VMOverrideList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VMOverrideList) DeepCopyObject ¶
func (in *VMOverrideList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*VMOverrideList) GetItems ¶
func (l *VMOverrideList) GetItems() []resource.Managed
GetItems of this VMOverrideList.
type VMOverrideObservation ¶
type VMOverrideObservation struct {
ID *string `json:"id,omitempty" tf:"id,omitempty"`
}
func (*VMOverrideObservation) DeepCopy ¶
func (in *VMOverrideObservation) DeepCopy() *VMOverrideObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VMOverrideObservation.
func (*VMOverrideObservation) DeepCopyInto ¶
func (in *VMOverrideObservation) DeepCopyInto(out *VMOverrideObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VMOverrideParameters ¶
type VMOverrideParameters struct {
// The managed object reference
// ID of the cluster to put the override in. Forces a new
// resource if changed.
// The managed object ID of the cluster.
// +kubebuilder:validation:Required
ComputeClusterID *string `json:"computeClusterId" tf:"compute_cluster_id,omitempty"`
// Controls the action to take
// on this virtual machine if an APD status on an affected datastore clears in
// the middle of an APD event. Can be one of useClusterDefault, none or
// reset. Default: useClusterDefault.
// *
// Controls the action to take on this virtual machine if an APD status on an affected datastore clears in the middle of an APD event. Can be one of useClusterDefault, none or reset.
// +kubebuilder:validation:Optional
HaDatastoreApdRecoveryAction *string `json:"haDatastoreApdRecoveryAction,omitempty" tf:"ha_datastore_apd_recovery_action,omitempty"`
// Controls the action to take on this
// virtual machine when the cluster has detected loss to all paths to a relevant
// datastore. Can be one of clusterDefault, disabled, warning,
// restartConservative, or restartAggressive. Default: clusterDefault.
// *
// Controls the action to take on this virtual machine when the cluster has detected loss to all paths to a relevant datastore. Can be one of clusterDefault, disabled, warning, restartConservative, or restartAggressive.
// +kubebuilder:validation:Optional
HaDatastoreApdResponse *string `json:"haDatastoreApdResponse,omitempty" tf:"ha_datastore_apd_response,omitempty"`
// Controls the delay in seconds
// to wait after an APD timeout event to execute the response action defined in
// ha_datastore_apd_response. Use -1 to use
// the cluster default. Default: -1.
// *
// Controls the delay in seconds to wait after an APD timeout event to execute the response action defined in ha_datastore_apd_response. Specify -1 to use the cluster setting.
// +kubebuilder:validation:Optional
HaDatastoreApdResponseDelay *float64 `json:"haDatastoreApdResponseDelay,omitempty" tf:"ha_datastore_apd_response_delay,omitempty"`
// Controls the action to take on this
// virtual machine when the cluster has detected a permanent device loss to a
// relevant datastore. Can be one of clusterDefault, disabled, warning, or
// restartAggressive. Default: clusterDefault.
// *
// Controls the action to take on this virtual machine when the cluster has detected a permanent device loss to a relevant datastore. Can be one of clusterDefault, disabled, warning, or restartAggressive.
// +kubebuilder:validation:Optional
HaDatastorePdlResponse *string `json:"haDatastorePdlResponse,omitempty" tf:"ha_datastore_pdl_response,omitempty"`
// The action to take on this virtual
// machine when a host has detected that it has been isolated from the rest of
// the cluster. Can be one of clusterIsolationResponse, none, powerOff, or
// shutdown. Default: clusterIsolationResponse.
// The action to take on this virtual machine when a host is isolated from the rest of the cluster. Can be one of clusterIsolationResponse, none, powerOff, or shutdown.
// +kubebuilder:validation:Optional
HaHostIsolationResponse *string `json:"haHostIsolationResponse,omitempty" tf:"ha_host_isolation_response,omitempty"`
// If a heartbeat from this virtual
// machine is not received within this configured interval, the virtual machine
// is marked as failed. The value is in seconds. Default: 30.
// If a heartbeat from this virtual machine is not received within this configured interval, the virtual machine is marked as failed. The value is in seconds.
// +kubebuilder:validation:Optional
HaVMFailureInterval *float64 `json:"haVmFailureInterval,omitempty" tf:"ha_vm_failure_interval,omitempty"`
// The length of the reset window in
// which ha_vm_maximum_resets can operate. When this
// window expires, no more resets are attempted regardless of the setting
// configured in ha_vm_maximum_resets. -1 means no window, meaning an
// unlimited reset time is allotted. The value is specified in seconds. Default:
// -1 (no window).
// The length of the reset window in which ha_vm_maximum_resets can operate. When this window expires, no more resets are attempted regardless of the setting configured in ha_vm_maximum_resets. -1 means no window, meaning an unlimited reset time is allotted.
// +kubebuilder:validation:Optional
HaVMMaximumFailureWindow *float64 `json:"haVmMaximumFailureWindow,omitempty" tf:"ha_vm_maximum_failure_window,omitempty"`
// The maximum number of resets that HA will
// perform to this virtual machine when responding to a failure event. Default:
// 3
// The maximum number of resets that HA will perform to this virtual machine when responding to a failure event.
// +kubebuilder:validation:Optional
HaVMMaximumResets *float64 `json:"haVmMaximumResets,omitempty" tf:"ha_vm_maximum_resets,omitempty"`
// The time, in seconds, that HA waits after
// powering on this virtual machine before monitoring for heartbeats. Default:
// 120 (2 minutes).
// The time, in seconds, that HA waits after powering on this virtual machine before monitoring for heartbeats.
// +kubebuilder:validation:Optional
HaVMMinimumUptime *float64 `json:"haVmMinimumUptime,omitempty" tf:"ha_vm_minimum_uptime,omitempty"`
// The type of virtual machine monitoring to use
// when HA is enabled in the cluster. Can be one of vmMonitoringDisabled,
// vmMonitoringOnly, or vmAndAppMonitoring. Default: vmMonitoringDisabled.
// The type of virtual machine monitoring to use for this virtual machine. Can be one of vmMonitoringDisabled, vmMonitoringOnly, or vmAndAppMonitoring.
// +kubebuilder:validation:Optional
HaVMMonitoring *string `json:"haVmMonitoring,omitempty" tf:"ha_vm_monitoring,omitempty"`
// Determines whether or
// not the cluster's default settings or the VM override settings specified in
// this resource are used for virtual machine monitoring. The default is true
// (use cluster defaults) - set to false to have overrides take effect.
// Determines whether or not the cluster's default settings or the VM override settings specified in this resource are used for virtual machine monitoring. The default is true (use cluster defaults) - set to false to have overrides take effect.
// +kubebuilder:validation:Optional
HaVMMonitoringUseClusterDefaults *bool `json:"haVmMonitoringUseClusterDefaults,omitempty" tf:"ha_vm_monitoring_use_cluster_defaults,omitempty"`
// The restart priority for the virtual
// machine when vSphere detects a host failure. Can be one of
// clusterRestartPriority, lowest, low, medium, high, highest, or disabled.
// Default: clusterRestartPriority.
// The restart priority for this virtual machine when vSphere detects a host failure. Can be one of clusterRestartPriority, lowest, low, medium, high, or highest.
// +kubebuilder:validation:Optional
HaVMRestartPriority *string `json:"haVmRestartPriority,omitempty" tf:"ha_vm_restart_priority,omitempty"`
// The maximum time, in seconds, that
// vSphere HA will wait for this virtual machine to be ready. Use -1 to
// specify the cluster default. Default: -1.
// *
// The maximum time, in seconds, that vSphere HA will wait for the virtual machine to be ready. Use -1 to use the cluster default.
// +kubebuilder:validation:Optional
HaVMRestartTimeout *float64 `json:"haVmRestartTimeout,omitempty" tf:"ha_vm_restart_timeout,omitempty"`
// The UUID of the virtual machine to create
// the override for. Forces a new resource if changed.
// The managed object ID of the virtual machine.
// +kubebuilder:validation:Required
VirtualMachineID *string `json:"virtualMachineId" tf:"virtual_machine_id,omitempty"`
}
func (*VMOverrideParameters) DeepCopy ¶
func (in *VMOverrideParameters) DeepCopy() *VMOverrideParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VMOverrideParameters.
func (*VMOverrideParameters) DeepCopyInto ¶
func (in *VMOverrideParameters) DeepCopyInto(out *VMOverrideParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VMOverrideSpec ¶
type VMOverrideSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider VMOverrideParameters `json:"forProvider"`
}
VMOverrideSpec defines the desired state of VMOverride
func (*VMOverrideSpec) DeepCopy ¶
func (in *VMOverrideSpec) DeepCopy() *VMOverrideSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VMOverrideSpec.
func (*VMOverrideSpec) DeepCopyInto ¶
func (in *VMOverrideSpec) DeepCopyInto(out *VMOverrideSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VMOverrideStatus ¶
type VMOverrideStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider VMOverrideObservation `json:"atProvider,omitempty"`
}
VMOverrideStatus defines the observed state of VMOverride.
func (*VMOverrideStatus) DeepCopy ¶
func (in *VMOverrideStatus) DeepCopy() *VMOverrideStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VMOverrideStatus.
func (*VMOverrideStatus) DeepCopyInto ¶
func (in *VMOverrideStatus) DeepCopyInto(out *VMOverrideStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.