Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=resourcepool.vsphere.upbound.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type Pool
- func (in *Pool) DeepCopy() *Pool
- func (in *Pool) DeepCopyInto(out *Pool)
- func (in *Pool) DeepCopyObject() runtime.Object
- func (mg *Pool) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *Pool) GetConnectionDetailsMapping() map[string]string
- func (mg *Pool) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *Pool) GetID() string
- func (tr *Pool) GetObservation() (map[string]any, error)
- func (tr *Pool) GetParameters() (map[string]any, error)
- func (mg *Pool) GetProviderConfigReference() *xpv1.Reference
- func (mg *Pool) GetProviderReference() *xpv1.Reference
- func (mg *Pool) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *Pool) GetTerraformResourceType() string
- func (tr *Pool) GetTerraformSchemaVersion() int
- func (mg *Pool) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *Pool) LateInitialize(attrs []byte) (bool, error)
- func (mg *Pool) SetConditions(c ...xpv1.Condition)
- func (mg *Pool) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (tr *Pool) SetObservation(obs map[string]any) error
- func (tr *Pool) SetParameters(params map[string]any) error
- func (mg *Pool) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *Pool) SetProviderReference(r *xpv1.Reference)
- func (mg *Pool) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *Pool) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type PoolList
- type PoolObservation
- type PoolParameters
- type PoolSpec
- type PoolStatus
Constants ¶
const ( CRDGroup = "resourcepool.vsphere.upbound.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( Pool_Kind = "Pool" Pool_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: Pool_Kind}.String() Pool_KindAPIVersion = Pool_Kind + "." + CRDGroupVersion.String() Pool_GroupVersionKind = CRDGroupVersion.WithKind(Pool_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type Pool ¶
type Pool struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec PoolSpec `json:"spec"`
Status PoolStatus `json:"status,omitempty"`
}
Pool is the Schema for the Pools API. Provides a resource for VMware vSphere resource pools. This can be used to create and manage resource pools. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,vsphere}
func (*Pool) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Pool.
func (*Pool) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Pool) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Pool) GetCondition ¶
func (mg *Pool) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this Pool.
func (*Pool) GetConnectionDetailsMapping ¶
GetConnectionDetailsMapping for this Pool
func (*Pool) GetDeletionPolicy ¶
func (mg *Pool) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this Pool.
func (*Pool) GetObservation ¶
GetObservation of this Pool
func (*Pool) GetParameters ¶
GetParameters of this Pool
func (*Pool) GetProviderConfigReference ¶
GetProviderConfigReference of this Pool.
func (*Pool) GetProviderReference ¶
GetProviderReference of this Pool. Deprecated: Use GetProviderConfigReference.
func (*Pool) GetPublishConnectionDetailsTo ¶
func (mg *Pool) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this Pool.
func (*Pool) GetTerraformResourceType ¶
GetTerraformResourceType returns Terraform resource type for this Pool
func (*Pool) GetTerraformSchemaVersion ¶
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*Pool) GetWriteConnectionSecretToReference ¶
func (mg *Pool) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this Pool.
func (*Pool) LateInitialize ¶
LateInitialize this Pool using its observed tfState. returns True if there are any spec changes for the resource.
func (*Pool) SetConditions ¶
SetConditions of this Pool.
func (*Pool) SetDeletionPolicy ¶
func (mg *Pool) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this Pool.
func (*Pool) SetObservation ¶
SetObservation for this Pool
func (*Pool) SetParameters ¶
SetParameters for this Pool
func (*Pool) SetProviderConfigReference ¶
SetProviderConfigReference of this Pool.
func (*Pool) SetProviderReference ¶
SetProviderReference of this Pool. Deprecated: Use SetProviderConfigReference.
func (*Pool) SetPublishConnectionDetailsTo ¶
func (mg *Pool) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this Pool.
func (*Pool) SetWriteConnectionSecretToReference ¶
func (mg *Pool) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this Pool.
type PoolList ¶
type PoolList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Pool `json:"items"`
}
PoolList contains a list of Pools
func (*PoolList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PoolList.
func (*PoolList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PoolList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PoolObservation ¶
type PoolObservation struct {
ID *string `json:"id,omitempty" tf:"id,omitempty"`
}
func (*PoolObservation) DeepCopy ¶
func (in *PoolObservation) DeepCopy() *PoolObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PoolObservation.
func (*PoolObservation) DeepCopyInto ¶
func (in *PoolObservation) DeepCopyInto(out *PoolObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PoolParameters ¶
type PoolParameters struct {
// Determines if the reservation on a resource
// pool can grow beyond the specified value if the parent resource pool has
// unreserved resources. Default: true
// Determines if the reservation on a resource pool can grow beyond the specified value, if the parent resource pool has unreserved resources.
// +kubebuilder:validation:Optional
CPUExpandable *bool `json:"cpuExpandable,omitempty" tf:"cpu_expandable,omitempty"`
// The CPU utilization of a resource pool will not
// exceed this limit, even if there are available resources. Set to -1 for
// unlimited. Default: -1
// The utilization of a resource pool will not exceed this limit, even if there are available resources. Set to -1 for unlimited.
// +kubebuilder:validation:Optional
CPULimit *float64 `json:"cpuLimit,omitempty" tf:"cpu_limit,omitempty"`
// Amount of CPU (MHz) that is guaranteed
// available to the resource pool. Default: 0
// Amount of CPU (MHz) that is guaranteed available to the resource pool.
// +kubebuilder:validation:Optional
CPUReservation *float64 `json:"cpuReservation,omitempty" tf:"cpu_reservation,omitempty"`
// simplified view of shares. Levels map to a pre-determined set of numeric
// values for shares. Can be one of low, normal, high, or custom. When
// low, normal, or high are specified values in cpu_shares will be
// ignored. Default: normal
// The allocation level. The level is a simplified view of shares. Levels map to a pre-determined set of numeric values for shares. Can be one of low, normal, high, or custom.
// +kubebuilder:validation:Optional
CPUShareLevel *string `json:"cpuShareLevel,omitempty" tf:"cpu_share_level,omitempty"`
// determine resource allocation in case of resource contention. If this is set,
// cpu_share_level must be custom.
// The number of shares allocated. Used to determine resource allocation in case of resource contention. If this is set, cpu_share_level must be custom.
// +kubebuilder:validation:Optional
CPUShares *float64 `json:"cpuShares,omitempty" tf:"cpu_shares,omitempty"`
// A list of custom attributes to set on this resource.
// +kubebuilder:validation:Optional
CustomAttributes map[string]*string `json:"customAttributes,omitempty" tf:"custom_attributes,omitempty"`
// Determines if the reservation on a resource
// pool can grow beyond the specified value if the parent resource pool has
// unreserved resources. Default: true
// Determines if the reservation on a resource pool can grow beyond the specified value, if the parent resource pool has unreserved resources.
// +kubebuilder:validation:Optional
MemoryExpandable *bool `json:"memoryExpandable,omitempty" tf:"memory_expandable,omitempty"`
// The CPU utilization of a resource pool will not
// exceed this limit, even if there are available resources. Set to -1 for
// unlimited. Default: -1
// The utilization of a resource pool will not exceed this limit, even if there are available resources. Set to -1 for unlimited.
// +kubebuilder:validation:Optional
MemoryLimit *float64 `json:"memoryLimit,omitempty" tf:"memory_limit,omitempty"`
// Amount of CPU (MHz) that is guaranteed
// available to the resource pool. Default: 0
// Amount of memory (MB) that is guaranteed available to the resource pool.
// +kubebuilder:validation:Optional
MemoryReservation *float64 `json:"memoryReservation,omitempty" tf:"memory_reservation,omitempty"`
// simplified view of shares. Levels map to a pre-determined set of numeric
// values for shares. Can be one of low, normal, high, or custom. When
// low, normal, or high are specified values in memory_shares will be
// ignored. Default: normal
// The allocation level. The level is a simplified view of shares. Levels map to a pre-determined set of numeric values for shares. Can be one of low, normal, high, or custom.
// +kubebuilder:validation:Optional
MemoryShareLevel *string `json:"memoryShareLevel,omitempty" tf:"memory_share_level,omitempty"`
// determine resource allocation in case of resource contention. If this is set,
// memory_share_level must be custom.
// The number of shares allocated. Used to determine resource allocation in case of resource contention. If this is set, memory_share_level must be custom.
// +kubebuilder:validation:Optional
MemoryShares *float64 `json:"memoryShares,omitempty" tf:"memory_shares,omitempty"`
// The name of the resource pool.
// Name of resource pool.
// +kubebuilder:validation:Required
Name *string `json:"name" tf:"name,omitempty"`
// The managed object ID
// of the parent resource pool. This can be the root resource pool for a cluster
// or standalone host, or a resource pool itself. When moving a resource pool
// from one parent resource pool to another, both must share a common root
// resource pool.
// The ID of the root resource pool of the compute resource the resource pool is in.
// +kubebuilder:validation:Required
ParentResourcePoolID *string `json:"parentResourcePoolId" tf:"parent_resource_pool_id,omitempty"`
// descendants of the resource pool are scaled up or down when the shares
// of the resource pool are scaled up or down. Can be one of disabled or
// scaleCpuAndMemoryShares. Default: disabled.
// Determines if the shares of all descendants of the resource pool are scaled up or down when the shares of the resource pool are scaled up or down.
// +kubebuilder:validation:Optional
ScaleDescendantsShares *string `json:"scaleDescendantsShares,omitempty" tf:"scale_descendants_shares,omitempty"`
// The IDs of any tags to attach to this resource. See
// here for a reference on how to apply tags.
// A list of tag IDs to apply to this object.
// +kubebuilder:validation:Optional
Tags []*string `json:"tags,omitempty" tf:"tags,omitempty"`
}
func (*PoolParameters) DeepCopy ¶
func (in *PoolParameters) DeepCopy() *PoolParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PoolParameters.
func (*PoolParameters) DeepCopyInto ¶
func (in *PoolParameters) DeepCopyInto(out *PoolParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PoolSpec ¶
type PoolSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider PoolParameters `json:"forProvider"`
}
PoolSpec defines the desired state of Pool
func (*PoolSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PoolSpec.
func (*PoolSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PoolStatus ¶
type PoolStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider PoolObservation `json:"atProvider,omitempty"`
}
PoolStatus defines the observed state of Pool.
func (*PoolStatus) DeepCopy ¶
func (in *PoolStatus) DeepCopy() *PoolStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PoolStatus.
func (*PoolStatus) DeepCopyInto ¶
func (in *PoolStatus) DeepCopyInto(out *PoolStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.