Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=tagcategory.vsphere.upbound.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type Category
- func (in *Category) DeepCopy() *Category
- func (in *Category) DeepCopyInto(out *Category)
- func (in *Category) DeepCopyObject() runtime.Object
- func (mg *Category) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *Category) GetConnectionDetailsMapping() map[string]string
- func (mg *Category) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *Category) GetID() string
- func (tr *Category) GetObservation() (map[string]any, error)
- func (tr *Category) GetParameters() (map[string]any, error)
- func (mg *Category) GetProviderConfigReference() *xpv1.Reference
- func (mg *Category) GetProviderReference() *xpv1.Reference
- func (mg *Category) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *Category) GetTerraformResourceType() string
- func (tr *Category) GetTerraformSchemaVersion() int
- func (mg *Category) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *Category) LateInitialize(attrs []byte) (bool, error)
- func (mg *Category) SetConditions(c ...xpv1.Condition)
- func (mg *Category) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (tr *Category) SetObservation(obs map[string]any) error
- func (tr *Category) SetParameters(params map[string]any) error
- func (mg *Category) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *Category) SetProviderReference(r *xpv1.Reference)
- func (mg *Category) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *Category) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type CategoryList
- type CategoryObservation
- type CategoryParameters
- type CategorySpec
- type CategoryStatus
Constants ¶
const ( CRDGroup = "tagcategory.vsphere.upbound.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( Category_Kind = "Category" Category_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: Category_Kind}.String() Category_KindAPIVersion = Category_Kind + "." + CRDGroupVersion.String() Category_GroupVersionKind = CRDGroupVersion.WithKind(Category_Kind) )
Repository type metadata.
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type Category ¶
type Category struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec CategorySpec `json:"spec"`
Status CategoryStatus `json:"status,omitempty"`
}
Category is the Schema for the Categorys API. Provides a vSphere tag category resource. This can be used to manage tag categories in vSphere. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,vsphere}
func (*Category) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Category.
func (*Category) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Category) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Category) GetCondition ¶
func (mg *Category) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this Category.
func (*Category) GetConnectionDetailsMapping ¶
GetConnectionDetailsMapping for this Category
func (*Category) GetDeletionPolicy ¶
func (mg *Category) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this Category.
func (*Category) GetObservation ¶
GetObservation of this Category
func (*Category) GetParameters ¶
GetParameters of this Category
func (*Category) GetProviderConfigReference ¶
GetProviderConfigReference of this Category.
func (*Category) GetProviderReference ¶
GetProviderReference of this Category. Deprecated: Use GetProviderConfigReference.
func (*Category) GetPublishConnectionDetailsTo ¶
func (mg *Category) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this Category.
func (*Category) GetTerraformResourceType ¶
GetTerraformResourceType returns Terraform resource type for this Category
func (*Category) GetTerraformSchemaVersion ¶
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*Category) GetWriteConnectionSecretToReference ¶
func (mg *Category) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this Category.
func (*Category) LateInitialize ¶
LateInitialize this Category using its observed tfState. returns True if there are any spec changes for the resource.
func (*Category) SetConditions ¶
SetConditions of this Category.
func (*Category) SetDeletionPolicy ¶
func (mg *Category) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this Category.
func (*Category) SetObservation ¶
SetObservation for this Category
func (*Category) SetParameters ¶
SetParameters for this Category
func (*Category) SetProviderConfigReference ¶
SetProviderConfigReference of this Category.
func (*Category) SetProviderReference ¶
SetProviderReference of this Category. Deprecated: Use SetProviderConfigReference.
func (*Category) SetPublishConnectionDetailsTo ¶
func (mg *Category) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this Category.
func (*Category) SetWriteConnectionSecretToReference ¶
func (mg *Category) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this Category.
type CategoryList ¶
type CategoryList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Category `json:"items"`
}
CategoryList contains a list of Categorys
func (*CategoryList) DeepCopy ¶
func (in *CategoryList) DeepCopy() *CategoryList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CategoryList.
func (*CategoryList) DeepCopyInto ¶
func (in *CategoryList) DeepCopyInto(out *CategoryList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CategoryList) DeepCopyObject ¶
func (in *CategoryList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*CategoryList) GetItems ¶
func (l *CategoryList) GetItems() []resource.Managed
GetItems of this CategoryList.
type CategoryObservation ¶
type CategoryObservation struct {
ID *string `json:"id,omitempty" tf:"id,omitempty"`
}
func (*CategoryObservation) DeepCopy ¶
func (in *CategoryObservation) DeepCopy() *CategoryObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CategoryObservation.
func (*CategoryObservation) DeepCopyInto ¶
func (in *CategoryObservation) DeepCopyInto(out *CategoryObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CategoryParameters ¶
type CategoryParameters struct {
// A list object types that this category is
// valid to be assigned to. For a full list, click
// here.
// Object types to which this category's tags can be attached. Valid types include: Folder, ClusterComputeResource, Datacenter, Datastore, StoragePod, DistributedVirtualPortgroup, DistributedVirtualSwitch, VmwareDistributedVirtualSwitch, HostSystem, com.vmware.content.Library, com.vmware.content.library.Item, HostNetwork, Network, OpaqueNetwork, ResourcePool, VirtualApp, VirtualMachine.
// +kubebuilder:validation:Required
AssociableTypes []*string `json:"associableTypes" tf:"associable_types,omitempty"`
// The number of tags that can be assigned from this
// category to a single object at once. Can be one of SINGLE (object can only
// be assigned one tag in this category), to MULTIPLE (object can be assigned
// multiple tags in this category). Forces a new resource if changed.
// The associated cardinality of the category. Can be one of SINGLE (object can only be assigned one tag in this category) or MULTIPLE (object can be assigned multiple tags in this category).
// +kubebuilder:validation:Required
Cardinality *string `json:"cardinality" tf:"cardinality,omitempty"`
// A description for the category.
// The description of the category.
// +kubebuilder:validation:Optional
Description *string `json:"description,omitempty" tf:"description,omitempty"`
}
func (*CategoryParameters) DeepCopy ¶
func (in *CategoryParameters) DeepCopy() *CategoryParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CategoryParameters.
func (*CategoryParameters) DeepCopyInto ¶
func (in *CategoryParameters) DeepCopyInto(out *CategoryParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CategorySpec ¶
type CategorySpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider CategoryParameters `json:"forProvider"`
}
CategorySpec defines the desired state of Category
func (*CategorySpec) DeepCopy ¶
func (in *CategorySpec) DeepCopy() *CategorySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CategorySpec.
func (*CategorySpec) DeepCopyInto ¶
func (in *CategorySpec) DeepCopyInto(out *CategorySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CategoryStatus ¶
type CategoryStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider CategoryObservation `json:"atProvider,omitempty"`
}
CategoryStatus defines the observed state of Category.
func (*CategoryStatus) DeepCopy ¶
func (in *CategoryStatus) DeepCopy() *CategoryStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CategoryStatus.
func (*CategoryStatus) DeepCopyInto ¶
func (in *CategoryStatus) DeepCopyInto(out *CategoryStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.