Documentation
¶
Overview ¶
+kubebuilder:object:generate=true +groupName=vnic.vsphere.upbound.io +versionName=v1alpha1
Index ¶
- Constants
- Variables
- type IPv4Observation
- type IPv4Parameters
- type IPv6Observation
- type IPv6Parameters
- type Vnic
- func (in *Vnic) DeepCopy() *Vnic
- func (in *Vnic) DeepCopyInto(out *Vnic)
- func (in *Vnic) DeepCopyObject() runtime.Object
- func (mg *Vnic) GetCondition(ct xpv1.ConditionType) xpv1.Condition
- func (tr *Vnic) GetConnectionDetailsMapping() map[string]string
- func (mg *Vnic) GetDeletionPolicy() xpv1.DeletionPolicy
- func (tr *Vnic) GetID() string
- func (tr *Vnic) GetObservation() (map[string]any, error)
- func (tr *Vnic) GetParameters() (map[string]any, error)
- func (mg *Vnic) GetProviderConfigReference() *xpv1.Reference
- func (mg *Vnic) GetProviderReference() *xpv1.Reference
- func (mg *Vnic) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
- func (mg *Vnic) GetTerraformResourceType() string
- func (tr *Vnic) GetTerraformSchemaVersion() int
- func (mg *Vnic) GetWriteConnectionSecretToReference() *xpv1.SecretReference
- func (tr *Vnic) LateInitialize(attrs []byte) (bool, error)
- func (mg *Vnic) SetConditions(c ...xpv1.Condition)
- func (mg *Vnic) SetDeletionPolicy(r xpv1.DeletionPolicy)
- func (tr *Vnic) SetObservation(obs map[string]any) error
- func (tr *Vnic) SetParameters(params map[string]any) error
- func (mg *Vnic) SetProviderConfigReference(r *xpv1.Reference)
- func (mg *Vnic) SetProviderReference(r *xpv1.Reference)
- func (mg *Vnic) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
- func (mg *Vnic) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
- type VnicList
- type VnicObservation
- type VnicParameters
- type VnicSpec
- type VnicStatus
Constants ¶
const ( CRDGroup = "vnic.vsphere.upbound.io" CRDVersion = "v1alpha1" )
Package type metadata.
Variables ¶
var ( // CRDGroupVersion is the API Group Version used to register the objects CRDGroupVersion = schema.GroupVersion{Group: CRDGroup, Version: CRDVersion} // SchemeBuilder is used to add go types to the GroupVersionKind scheme SchemeBuilder = &scheme.Builder{GroupVersion: CRDGroupVersion} // AddToScheme adds the types in this group-version to the given scheme. AddToScheme = SchemeBuilder.AddToScheme )
var ( Vnic_Kind = "Vnic" Vnic_GroupKind = schema.GroupKind{Group: CRDGroup, Kind: Vnic_Kind}.String() Vnic_KindAPIVersion = Vnic_Kind + "." + CRDGroupVersion.String() Vnic_GroupVersionKind = CRDGroupVersion.WithKind(Vnic_Kind) )
Repository type metadata.
Functions ¶
This section is empty.
Types ¶
type IPv4Observation ¶
type IPv4Observation struct {
}
func (*IPv4Observation) DeepCopy ¶
func (in *IPv4Observation) DeepCopy() *IPv4Observation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPv4Observation.
func (*IPv4Observation) DeepCopyInto ¶
func (in *IPv4Observation) DeepCopyInto(out *IPv4Observation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IPv4Parameters ¶
type IPv4Parameters struct {
// Use DHCP to configure the interface's IPv4 stack.
// Use DHCP to configure the interface's IPv4 stack.
// +kubebuilder:validation:Optional
DHCP *bool `json:"dhcp,omitempty" tf:"dhcp,omitempty"`
// IP address of the default gateway, if DHCP is not set.
// IP address of the default gateway, if DHCP is not set.
// +kubebuilder:validation:Optional
Gw *string `json:"gw,omitempty" tf:"gw,omitempty"`
// Address of the interface, if DHCP is not set.
// address of the interface, if DHCP is not set.
// +kubebuilder:validation:Optional
IP *string `json:"ip,omitempty" tf:"ip,omitempty"`
// Netmask of the interface, if DHCP is not set.
// netmask of the interface, if DHCP is not set.
// +kubebuilder:validation:Optional
Netmask *string `json:"netmask,omitempty" tf:"netmask,omitempty"`
}
func (*IPv4Parameters) DeepCopy ¶
func (in *IPv4Parameters) DeepCopy() *IPv4Parameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPv4Parameters.
func (*IPv4Parameters) DeepCopyInto ¶
func (in *IPv4Parameters) DeepCopyInto(out *IPv4Parameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IPv6Observation ¶
type IPv6Observation struct {
}
func (*IPv6Observation) DeepCopy ¶
func (in *IPv6Observation) DeepCopy() *IPv6Observation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPv6Observation.
func (*IPv6Observation) DeepCopyInto ¶
func (in *IPv6Observation) DeepCopyInto(out *IPv6Observation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IPv6Parameters ¶
type IPv6Parameters struct {
// List of IPv6 addresses
// List of IPv6 addresses
// +kubebuilder:validation:Optional
Addresses []*string `json:"addresses,omitempty" tf:"addresses,omitempty"`
// Use IPv6 Autoconfiguration (RFC2462).
// Use IPv6 Autoconfiguration (RFC2462).
// +kubebuilder:validation:Optional
Autoconfig *bool `json:"autoconfig,omitempty" tf:"autoconfig,omitempty"`
// Use DHCP to configure the interface's IPv4 stack.
// Use DHCP to configure the interface's IPv4 stack.
// +kubebuilder:validation:Optional
DHCP *bool `json:"dhcp,omitempty" tf:"dhcp,omitempty"`
// IP address of the default gateway, if DHCP is not set.
// IP address of the default gateway, if DHCP or autoconfig is not set.
// +kubebuilder:validation:Optional
Gw *string `json:"gw,omitempty" tf:"gw,omitempty"`
}
func (*IPv6Parameters) DeepCopy ¶
func (in *IPv6Parameters) DeepCopy() *IPv6Parameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IPv6Parameters.
func (*IPv6Parameters) DeepCopyInto ¶
func (in *IPv6Parameters) DeepCopyInto(out *IPv6Parameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Vnic ¶
type Vnic struct {
metav1.TypeMeta `json:",inline"`
metav1.ObjectMeta `json:"metadata,omitempty"`
Spec VnicSpec `json:"spec"`
Status VnicStatus `json:"status,omitempty"`
}
Vnic is the Schema for the Vnics API. Provides a VMware vSphere vnic resource.. +kubebuilder:printcolumn:name="READY",type="string",JSONPath=".status.conditions[?(@.type=='Ready')].status" +kubebuilder:printcolumn:name="SYNCED",type="string",JSONPath=".status.conditions[?(@.type=='Synced')].status" +kubebuilder:printcolumn:name="EXTERNAL-NAME",type="string",JSONPath=".metadata.annotations.crossplane\\.io/external-name" +kubebuilder:printcolumn:name="AGE",type="date",JSONPath=".metadata.creationTimestamp" +kubebuilder:subresource:status +kubebuilder:resource:scope=Cluster,categories={crossplane,managed,vsphere}
func (*Vnic) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Vnic.
func (*Vnic) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Vnic) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
func (*Vnic) GetCondition ¶
func (mg *Vnic) GetCondition(ct xpv1.ConditionType) xpv1.Condition
GetCondition of this Vnic.
func (*Vnic) GetConnectionDetailsMapping ¶
GetConnectionDetailsMapping for this Vnic
func (*Vnic) GetDeletionPolicy ¶
func (mg *Vnic) GetDeletionPolicy() xpv1.DeletionPolicy
GetDeletionPolicy of this Vnic.
func (*Vnic) GetObservation ¶
GetObservation of this Vnic
func (*Vnic) GetParameters ¶
GetParameters of this Vnic
func (*Vnic) GetProviderConfigReference ¶
GetProviderConfigReference of this Vnic.
func (*Vnic) GetProviderReference ¶
GetProviderReference of this Vnic. Deprecated: Use GetProviderConfigReference.
func (*Vnic) GetPublishConnectionDetailsTo ¶
func (mg *Vnic) GetPublishConnectionDetailsTo() *xpv1.PublishConnectionDetailsTo
GetPublishConnectionDetailsTo of this Vnic.
func (*Vnic) GetTerraformResourceType ¶
GetTerraformResourceType returns Terraform resource type for this Vnic
func (*Vnic) GetTerraformSchemaVersion ¶
GetTerraformSchemaVersion returns the associated Terraform schema version
func (*Vnic) GetWriteConnectionSecretToReference ¶
func (mg *Vnic) GetWriteConnectionSecretToReference() *xpv1.SecretReference
GetWriteConnectionSecretToReference of this Vnic.
func (*Vnic) LateInitialize ¶
LateInitialize this Vnic using its observed tfState. returns True if there are any spec changes for the resource.
func (*Vnic) SetConditions ¶
SetConditions of this Vnic.
func (*Vnic) SetDeletionPolicy ¶
func (mg *Vnic) SetDeletionPolicy(r xpv1.DeletionPolicy)
SetDeletionPolicy of this Vnic.
func (*Vnic) SetObservation ¶
SetObservation for this Vnic
func (*Vnic) SetParameters ¶
SetParameters for this Vnic
func (*Vnic) SetProviderConfigReference ¶
SetProviderConfigReference of this Vnic.
func (*Vnic) SetProviderReference ¶
SetProviderReference of this Vnic. Deprecated: Use SetProviderConfigReference.
func (*Vnic) SetPublishConnectionDetailsTo ¶
func (mg *Vnic) SetPublishConnectionDetailsTo(r *xpv1.PublishConnectionDetailsTo)
SetPublishConnectionDetailsTo of this Vnic.
func (*Vnic) SetWriteConnectionSecretToReference ¶
func (mg *Vnic) SetWriteConnectionSecretToReference(r *xpv1.SecretReference)
SetWriteConnectionSecretToReference of this Vnic.
type VnicList ¶
type VnicList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata,omitempty"`
Items []Vnic `json:"items"`
}
VnicList contains a list of Vnics
func (*VnicList) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VnicList.
func (*VnicList) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*VnicList) DeepCopyObject ¶
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type VnicObservation ¶
type VnicObservation struct {
// The ID of the vNic.
ID *string `json:"id,omitempty" tf:"id,omitempty"`
}
func (*VnicObservation) DeepCopy ¶
func (in *VnicObservation) DeepCopy() *VnicObservation
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VnicObservation.
func (*VnicObservation) DeepCopyInto ¶
func (in *VnicObservation) DeepCopyInto(out *VnicObservation)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VnicParameters ¶
type VnicParameters struct {
// Key of the distributed portgroup the nic will connect to.
// Key of the distributed portgroup the nic will connect to
// +kubebuilder:validation:Optional
DistributedPortGroup *string `json:"distributedPortGroup,omitempty" tf:"distributed_port_group,omitempty"`
// UUID of the DVSwitch the nic will be attached to. Do not set if you set portgroup.
// UUID of the DVSwitch the nic will be attached to. Do not set if you set portgroup.
// +kubebuilder:validation:Optional
DistributedSwitchPort *string `json:"distributedSwitchPort,omitempty" tf:"distributed_switch_port,omitempty"`
// ESX host the interface belongs to
// +kubebuilder:validation:Required
Host *string `json:"host" tf:"host,omitempty"`
// IPv4 settings. Either this or ipv6 needs to be set. See ipv4 options below.
// +kubebuilder:validation:Optional
IPv4 []IPv4Parameters `json:"ipv4,omitempty" tf:"ipv4,omitempty"`
// IPv6 settings. Either this or ipv6 needs to be set. See ipv6 options below.
// +kubebuilder:validation:Optional
IPv6 []IPv6Parameters `json:"ipv6,omitempty" tf:"ipv6,omitempty"`
// MAC address of the interface.
// MAC address of the interface.
// +kubebuilder:validation:Optional
Mac *string `json:"mac,omitempty" tf:"mac,omitempty"`
// MTU of the interface.
// MTU of the interface.
// +kubebuilder:validation:Optional
Mtu *float64 `json:"mtu,omitempty" tf:"mtu,omitempty"`
// TCP/IP stack setting for this interface. Possible values are 'defaultTcpipStack', 'vmotion', 'vSphereProvisioning'. Changing this will force the creation of a new interface since it's not possible to change the stack once it gets created. (Default: defaultTcpipStack)
// TCP/IP stack setting for this interface. Possible values are 'defaultTcpipStack', 'vmotion', 'provisioning'
// +kubebuilder:validation:Optional
Netstack *string `json:"netstack,omitempty" tf:"netstack,omitempty"`
// Portgroup to attach the nic to. Do not set if you set distributed_switch_port.
// portgroup to attach the nic to. Do not set if you set distributed_switch_port.
// +kubebuilder:validation:Optional
Portgroup *string `json:"portgroup,omitempty" tf:"portgroup,omitempty"`
}
func (*VnicParameters) DeepCopy ¶
func (in *VnicParameters) DeepCopy() *VnicParameters
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VnicParameters.
func (*VnicParameters) DeepCopyInto ¶
func (in *VnicParameters) DeepCopyInto(out *VnicParameters)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VnicSpec ¶
type VnicSpec struct {
v1.ResourceSpec `json:",inline"`
ForProvider VnicParameters `json:"forProvider"`
}
VnicSpec defines the desired state of Vnic
func (*VnicSpec) DeepCopy ¶
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VnicSpec.
func (*VnicSpec) DeepCopyInto ¶
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type VnicStatus ¶
type VnicStatus struct {
v1.ResourceStatus `json:",inline"`
AtProvider VnicObservation `json:"atProvider,omitempty"`
}
VnicStatus defines the observed state of Vnic.
func (*VnicStatus) DeepCopy ¶
func (in *VnicStatus) DeepCopy() *VnicStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new VnicStatus.
func (*VnicStatus) DeepCopyInto ¶
func (in *VnicStatus) DeepCopyInto(out *VnicStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.